/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalDel1.h"
#include "HvSignalLine.h"
#include "HvSignalRPole.h"
#include "HvControlIf.h"
#include "HvControlRandom.h"
#include "HvSignalTabread.h"
#include "HvControlCast.h"
#include "HvControlTabhead.h"
#include "HvControlSlice.h"
#include "HvTable.h"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvControlSystem.h"
#include "HvMath.h"
#include "HvSignalPhasor.h"
#include "HvControlPack.h"
#include "HvSignalTabwrite.h"
#include "HvControlUnop.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_0yBYa0wm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XFEgbzvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_5QkQiPNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_a1WOw0RL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d3cICdEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_z3zlV9GE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_0IABOYzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qYCweP8T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zONIJThz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QavO5ehE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SRTKOlGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_V73pJ6pf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xsO59CT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0nvxcqi6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_IU73MOyc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_slYmAgul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i1cTH0Mh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WZbF8muB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SdLPxQIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xLbs3yKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RKYtj20t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dommpvsx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mKa4R9Ra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lBRSZ2GU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lO0N0vfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cT8i3V6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QDlHgl1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9JbwkoMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3D0RW3Xb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m8A4XvIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_x5U6svqQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3jFLkH1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oM6zmVXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7J6yD3Fu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OwXHDHJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mVPRA0O2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eoSKZGeN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zg1qVRtQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5HPw8Dqf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GqbMohzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GnNwPjAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ks2XFugz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qjYBCf34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BsEAYlrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h1KliAMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NOZXvnJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jZhI0fvY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_jMtUtmHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VHoh7U9C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LaW8Qpe4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sDDQieiw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wthftv84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nSbWqOgd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0F9EVmSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JP21U8sO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qt1Oou1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4M1yo1gi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gd6UmXBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J1pdm4dQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bun04vPA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f1UoLbwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bJGs6acw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i445Vj5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_W4T1IVgY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_1VjimSbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Dv3QbVfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_wlLhYcC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_vRKjOgr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UOPM5CAn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7acqyRqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JVg9hkks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_62V7fRcm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_09s8WICu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iZViNGBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HtqDEYzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_14K7k8r9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1I59E94h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aSrOEwuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_MGwj9Nid_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qj7AC8tQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_t2zYROFV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ln8eloxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PoZef20Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xKxzvcC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_UoQ0vKCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zg3aum4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qsQXsOI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Aq9UeSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6WaYni3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RoIE8UIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F3BEWI9C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XIaSgd3R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VotZOmbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k1GxmaqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YRQHhvpp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f3f69OGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wPEfOQG7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_ht8yPDP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VbLG2YRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_f24J1qym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f4QIigP8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IN88dgW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3DyCHv6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_S7xJkpS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_byTNMob1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P0pSzGhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Y3ZiPNl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BSqfBQrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MQUotpiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_shjreKhs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cH7ShmiZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kun3ViuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HT4fWIKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_numAV2Fc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n6UwA2tu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3p3IugjF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_9LPq23HG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6zNeq73S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JweFN5gl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IdzeTBDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ykD40xTi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kVRJgQJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_x0pWAuRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ohhmieb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z25tBp4L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_01FQ8edb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WM3MFVqJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NPTV2RRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mqwdfxL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tiCfMp5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H8q7VqaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cozk6cZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jVNB2V8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UYpJDZ64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ObJxhqln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_A0aSLEpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g5sgzVUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AOLHTHVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3veFdNr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fkhg2ba4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KYs1Yfuj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ttPuCrK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CTHILY71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pn46GA8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t6XGvMSv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qXO2yqZN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m5J0VDri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_38MAjBAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FC2HBuZd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eAveW25X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p3UdnH4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yc1mkSLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y3J8tzcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4W5d7CRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCDiCQz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8VtKrvIi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1QiNPfk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QF8BX84V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_R2IQhoY2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Oi0yljSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_WrDyEsyh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JokX5uOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s9aNCpAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iO8ZBx9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QCrimJlI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RXPU2zkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oZtW7ZmG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tVDEVsh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FDviMPdX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SRCzwI6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_M1kVQ2CK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OV8ndZHQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_PtctDk7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_zVxuWmbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pgYlMVMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IEudVhbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wKAsQ9aF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UdVcAnpR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CK5hb1Zb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k6OvjmJU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ba3XQTw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rDxzxtFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_za2DeifV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HyZbH4Cs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lmXgS3RA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_aN8B92Cl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_glpRfysY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yZKVPDyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cQ1c4gi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n16ikjKk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WAGR6bPd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nUNN4ytE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vprmC72L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9HJWqs6M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vhcDeJ0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_td6dYAEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_S9sVtf8h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5u44pXIS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_59yj875g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_4XUDdaNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vCkHrcI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_exvLzd6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iCViak7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p3XY6GpI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PVy4cHWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xgpPxLSW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_sslaJDLL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_i3VtgeCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rtZtDge2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e0T024Ts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LQ7Uy73Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ub5XrkaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jM2KkQyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HsLUivEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W2CpwBRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jRjaIfhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CDCAZEC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i1a8rzz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t78OsyQW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Sb3msu5S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qPswlB5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rrpl4jes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dLKsQoj0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wFDJExrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4GHJ2yjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6erlmA2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R1fMT7M4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UikRYH61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OgkOJsD7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zpPkhuzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kJSspeuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VV5ZGEHQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_lQZSwdxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_00dwCZyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z5qZuLFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0dJOA3GR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_umKo0w9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Uut2vlhN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hn4cN6n5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V0ge2EX3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_nu3yr8jY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KREWiVtu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FK2XxHrX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sGVA8tu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bGrs1Z2t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JkXcy9Fg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_k9qNzWUH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IxOAtp6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O1gFRLvE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kb3oMvoy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fwR3BNln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J1fX2LS6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JRWL5Z9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bhlVoelI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ygvDRX0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r8osOAC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tcurz7kM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ftTNl326_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tcvi2f12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ucxX5WIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KMAEv8St_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ltkTCAOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zqNl1EdY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_21r4qgHv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_NFeE4gli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_kiB7ZZsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IKeMu02t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HgcR4ASd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YX0VRwtm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5UzYo420_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SFdaYri1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XaVsA9cc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_JwAzpeA3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NqpNgXv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mA8lQi4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FVZAI5He_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BZfoh41d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TmaTojev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ND6Qevho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UhuNsDeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jS6OzgyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DCKVMiXz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PQ0vbzdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cVjDhp67_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GkcmvXMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y0OkFtEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eaf84Jp4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q7blpZqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6yL9ythZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uaT91nnW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M7GscuGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nQeGRkHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_drzuqhYS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AYkluoWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EEoNKK6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hdcXnqjc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_zBKuMnC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_dOOXAKYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCKtnfcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CUznyTDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DaEQCjbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4TQSl2Ov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jJtuBnYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qYELv9IV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_6JldcV9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G2QOlwh7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_45LEdCLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NWvma2sh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JcAaMisi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6l96BVQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_lpoU3cAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kmEZgEYj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yCYSkDjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EWesMM5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8vtEKEbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Noq0F4uA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Oog9KdV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_htp5mY6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z8rybyIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GbnIQoTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MZc5Tz2w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GIoBNiCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I2dkhvtW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SFrczmDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ccMK73yF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_THHfAEYq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wCBgeqzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GaEq6lXV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_SLVDLBXC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_u8Ki07XJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CIqjDmpl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_anIA1nsT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6hcgXoFb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F61g8nbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IQeuAzcR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QTsPnp7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_PTyCCfqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_znrmieaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Ku5ZSO3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ONIUnS9l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KJgRwDOK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iSYhq1ua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ty0k8Ros_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_chZVff0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RGvQbsMF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_78c2qq9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r6znkUwa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZsMW14bb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JREnk2XQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hZYJrYhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dS5DDe2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MOIPCeOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KaZRFf8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nfGNihvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4lmcWx8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FSbIqJi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_h4nyjOqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DpDEMOYZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_30ImelmY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GeWK1pQ0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_91Fe4Z7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_rOY9kfy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_in4NXhUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bkIdbIOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JBebeSXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xqdhfs7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dmxbfmhZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PngwMt2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_gMHI4n5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_McuBaCDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NzC8OmfR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_30oCpuNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UevsEoYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HOW6z604_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Uhcv57ms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wBw3bCBP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_itL7IqNl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SsBf06Qr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VwRlTAFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QHfC9qwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iSdO94zE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ej9Gjrz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ckd75gKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X70RzQP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KxAZcFJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hE3NUL99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mYxeEien_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dqDmw13r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RQNu20sy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dUnxNnXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tzM4CHIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IeI5ojiA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_XtIWXmTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_TPX2aUYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4aCsqjLi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OcLmNWnw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SEQjVsXC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hc3rRVoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wggcPKwl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zkHLurIl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_vkp0pxjB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ULpLAbd0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_j76Qildp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ENbtR69T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1IhddQu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_jARMdbvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_xkzta5HU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kqNABIh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IiZbv6IH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jbQQRUar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Ll3VOl0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0Ne0bS2u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xzJJOzn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RyMzMOq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zgyjSQdr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SQ9a00RQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iNWI7fXK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fkDIqTHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ATcLMJFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6FSzTCbJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GVVDrayn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ZRFxjNoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JdLFrBBv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TnBJxHmc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_d9TdFY6y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yLa8SbA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3zyR2Nnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jbBP1282_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AmJGBbjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_el1WTBix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mYWfDJ7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m2VCZqqs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xJABeDwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Z0UwMsOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IvPJbE6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kzk8ugNF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aPpXNmrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uXngXIHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cf3IASoS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IqvgcvKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MVK3sVDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0w7CcesD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZPJQS6qW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kPCJeiAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qlwai7tm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sSMhgtJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CAIRRRqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0T8n6JdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7FsFGWTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cktvigB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g21Oxk4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q4IxNzNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iblLCVTP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GJzEKMRA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_cFYsL34s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1esBkXxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fyN4GHmM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_G0czi4sh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SmUxTTYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ouzELE3b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j4rEFGsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EGrGjqjC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7PgJGQ1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jN7qYR6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mL7d4R82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DOnSP4cH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ZoRyefwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3vkpVd19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J0WGoSv6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fAr2GKRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_saDaTplh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_y0VvwmZa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LHnv6lY2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Yf5aqF2T_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_eKsJDMgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_pL6tXkvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6aEu6NQG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qgSuf1Eh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VJErq6WH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CYzBfWI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oZPWBmum_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rLEh0Vmr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_QcoDdV1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aYfvCA0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5gU1dy3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mDpUoG2T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_0Bhw2Y1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RJp18UEI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_8CL64JUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XydBZroK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s8rhR9mf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B2dz2tW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vaTVIGKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vnuuUYS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vPpZ9TbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BaZfrACR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KPLa4LXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rZf5FHGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qyd9y177_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ioKPWgCh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BLn0fns5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PEg4CixI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_S8OyKJU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kPquj3oT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rN8skTrS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_YuqUQDXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OBTS3FgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4PDJSD6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CC7o3Nrx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jVyfnYoZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ydJzJNsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rH3Sx7kw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_O9sMtwBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xPHgj3KT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zl5iAOnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7xTWCzNT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GkBtZw2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LPueh9Ul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kLcuxDza_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5S9bRQj0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pu8lqPWe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_IVEnlmFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_OUrAoUFp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_q21putqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lKgjFa6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_syNqpuMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nS5skm1N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N4pFfGdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_toPaKYVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Web9D8mS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0JuNAvFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LYdjdLWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_O9lkr9Ts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nf8Sp4Ar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_k08280IG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9gY9NSUC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mjxu2Yqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8o7BFj5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rwyqBu9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ir11yASN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JTztm6B4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qzk6nmxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3RCwtewE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qbtuQ1Dz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UQ9P5d6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A8zgVzRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PLOTSogW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_evaVesYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3gzOIl9E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2qfkIPed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kdNvEWBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WJNHyY4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lMCeR05l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_diBUbZde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oYWCPpCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L3k96Y1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5T8aoSIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iuW79QQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hs1W8hnR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wtSoDNbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fNd2xibE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xyxw7h7R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YItALXs2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fzbz7QoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XVCGnkBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LrxX92lR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AkwMCd7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BlYHhPHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7OiSWEtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZjzpdXjI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lYNJjWHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ibdxxev7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wgl9bkov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gGZMaVEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gx5Jbbj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gjtnYbeE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DQOAOi0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0OQjflgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JmhouV5D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z3oi8S2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mJcgQSOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aUab1fDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pzpSrTyl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_X6Dwjhd4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7WLPvbdj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kwa9qNLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YrYP88Yv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BGvFqjmk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Gh1y0I3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_caG62iMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kS2iQooj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tFUwdQsc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4ntEUaj9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tv8SeIkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eXz4z9oQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_91uMFuBS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_en8K2huC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oTo5enLY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rNd5C1Hx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FiXPPwnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jqRzHgu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2xfLWu1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fUynZdpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3Wmc3ZMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yrwicUs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_ppRcYNGN;
  SignalLine sLine_lch0oisU;
  SignalLine sLine_Tvq6peL0;
  SignalTabhead sTabhead_wEIul4rI;
  SignalTabread sTabread_4lq60lga;
  SignalTabread sTabread_VT0SnUzQ;
  SignalTabhead sTabhead_8xJKFYgk;
  SignalTabread sTabread_jikl2ZIm;
  SignalTabread sTabread_YuN3e68Q;
  SignalTabwrite sTabwrite_l0v3pjVv;
  SignalRPole sRPole_sJDesaqr;
  SignalDel1 sDel1_xtJFhx0L;
  SignalTabread sTabread_8CL64JUv;
  SignalTabwrite sTabwrite_Gi2itpse;
  SignalTabread sTabread_UoQ0vKCA;
  SignalRPole sRPole_JzAlQyH5;
  SignalLine sLine_dAYgHCK0;
  SignalLine sLine_xanK1odK;
  SignalTabread sTabread_k9qNzWUH;
  SignalTabread sTabread_ND6Qevho;
  SignalTabread sTabread_lpoU3cAm;
  SignalTabread sTabread_ty0k8Ros;
  SignalTabread sTabread_xkzta5HU;
  SignalTabread sTabread_Uhcv57ms;
  SignalTabwrite sTabwrite_ClZu3Zl9;
  SignalTabwrite sTabwrite_3hr2lOhj;
  SignalTabwrite sTabwrite_T6lcn9rJ;
  SignalTabwrite sTabwrite_ETw3W8dB;
  SignalTabwrite sTabwrite_lc4Ag43H;
  SignalTabwrite sTabwrite_r7FOShdG;
  SignalTabread sTabread_S7xJkpS3;
  SignalRPole sRPole_9iABMgkg;
  SignalTabread sTabread_x0pWAuRM;
  SignalRPole sRPole_VuLQRRTZ;
  SignalTabread sTabread_ttPuCrK9;
  SignalRPole sRPole_m9O1ThvH;
  SignalTabwrite sTabwrite_eErH9xec;
  SignalTabwrite sTabwrite_J9IhJjcq;
  SignalTabwrite sTabwrite_B4ISYUzw;
  SignalTabwrite sTabwrite_RlipCkZz;
  SignalLine sLine_rzfDCGjt;
  ControlVar cVar_0yBYa0wm;
  ControlVar cVar_XFEgbzvp;
  ControlPack cPack_5QkQiPNQ;
  ControlBinop cBinop_d3cICdEa;
  ControlVar cVar_z3zlV9GE;
  ControlPack cPack_0IABOYzF;
  ControlVar cVar_qYCweP8T;
  ControlVar cVar_zONIJThz;
  ControlDelay cDelay_V73pJ6pf;
  ControlDelay cDelay_xsO59CT6;
  ControlBinop cBinop_IU73MOyc;
  HvTable hTable_slYmAgul;
  ControlBinop cBinop_WZbF8muB;
  ControlVar cVar_lO0N0vfP;
  ControlBinop cBinop_QDlHgl1Y;
  ControlBinop cBinop_3D0RW3Xb;
  SignalVarf sVarf_QtIL0rn0;
  SignalVarf sVarf_XS4FGTD5;
  SignalVarf sVarf_0UvsKo7Z;
  ControlVar cVar_3jFLkH1g;
  ControlBinop cBinop_7J6yD3Fu;
  ControlBinop cBinop_mVPRA0O2;
  SignalVarf sVarf_3kmzPTfP;
  SignalVarf sVarf_6K12GXX9;
  SignalVarf sVarf_cdZWQDfu;
  ControlBinop cBinop_eoSKZGeN;
  ControlBinop cBinop_Zg1qVRtQ;
  ControlBinop cBinop_GnNwPjAy;
  ControlBinop cBinop_ks2XFugz;
  ControlBinop cBinop_qjYBCf34;
  ControlBinop cBinop_BsEAYlrQ;
  ControlBinop cBinop_h1KliAMI;
  ControlBinop cBinop_sDDQieiw;
  ControlBinop cBinop_wthftv84;
  SignalVarf sVarf_8ast95bf;
  ControlVar cVar_nSbWqOgd;
  ControlBinop cBinop_qt1Oou1v;
  ControlBinop cBinop_4M1yo1gi;
  ControlBinop cBinop_J1pdm4dQ;
  ControlBinop cBinop_Bun04vPA;
  ControlBinop cBinop_f1UoLbwG;
  ControlBinop cBinop_bJGs6acw;
  ControlBinop cBinop_i445Vj5U;
  SignalVarf sVarf_Mx6fcBx8;
  ControlBinop cBinop_1VjimSbv;
  ControlRandom cRandom_wlLhYcC2;
  ControlSlice cSlice_vRKjOgr6;
  ControlDelay cDelay_7acqyRqu;
  ControlVar cVar_iZViNGBn;
  ControlBinop cBinop_14K7k8r9;
  ControlBinop cBinop_1I59E94h;
  ControlBinop cBinop_aSrOEwuE;
  ControlTabhead cTabhead_MGwj9Nid;
  ControlVar cVar_Ln8eloxK;
  ControlDelay cDelay_PoZef20Y;
  ControlDelay cDelay_xKxzvcC6;
  ControlBinop cBinop_Zg3aum4N;
  ControlBinop cBinop_qsQXsOI1;
  ControlBinop cBinop_8Aq9UeSb;
  ControlBinop cBinop_VotZOmbY;
  ControlBinop cBinop_YRQHhvpp;
  ControlBinop cBinop_f3f69OGM;
  ControlTabhead cTabhead_ht8yPDP4;
  ControlVar cVar_f4QIigP8;
  ControlDelay cDelay_IN88dgW6;
  ControlDelay cDelay_3DyCHv6C;
  ControlBinop cBinop_byTNMob1;
  ControlBinop cBinop_P0pSzGhL;
  ControlBinop cBinop_1Y3ZiPNl;
  ControlBinop cBinop_kun3ViuV;
  ControlBinop cBinop_numAV2Fc;
  ControlBinop cBinop_n6UwA2tu;
  ControlTabhead cTabhead_9LPq23HG;
  ControlVar cVar_IdzeTBDq;
  ControlDelay cDelay_ykD40xTi;
  ControlDelay cDelay_kVRJgQJa;
  ControlBinop cBinop_Ohhmieb3;
  ControlBinop cBinop_Z25tBp4L;
  ControlBinop cBinop_01FQ8edb;
  ControlBinop cBinop_H8q7VqaS;
  ControlBinop cBinop_jVNB2V8K;
  ControlBinop cBinop_UYpJDZ64;
  ControlTabhead cTabhead_A0aSLEpF;
  ControlVar cVar_3veFdNr4;
  ControlDelay cDelay_fkhg2ba4;
  ControlDelay cDelay_KYs1Yfuj;
  ControlBinop cBinop_CTHILY71;
  ControlBinop cBinop_pn46GA8U;
  ControlBinop cBinop_t6XGvMSv;
  ControlBinop cBinop_eAveW25X;
  ControlBinop cBinop_yc1mkSLk;
  ControlBinop cBinop_y3J8tzcj;
  ControlDelay cDelay_1QiNPfk8;
  ControlDelay cDelay_QF8BX84V;
  ControlBinop cBinop_Oi0yljSQ;
  HvTable hTable_WrDyEsyh;
  ControlBinop cBinop_s9aNCpAO;
  ControlDelay cDelay_SRCzwI6K;
  ControlDelay cDelay_M1kVQ2CK;
  ControlBinop cBinop_PtctDk7q;
  HvTable hTable_zVxuWmbl;
  ControlBinop cBinop_IEudVhbc;
  ControlDelay cDelay_za2DeifV;
  ControlDelay cDelay_HyZbH4Cs;
  ControlBinop cBinop_aN8B92Cl;
  HvTable hTable_glpRfysY;
  ControlBinop cBinop_cQ1c4gi3;
  ControlDelay cDelay_td6dYAEJ;
  ControlDelay cDelay_S9sVtf8h;
  ControlBinop cBinop_59yj875g;
  HvTable hTable_4XUDdaNR;
  ControlBinop cBinop_exvLzd6Q;
  ControlPack cPack_sslaJDLL;
  ControlPack cPack_i3VtgeCa;
  ControlBinop cBinop_rtZtDge2;
  ControlBinop cBinop_e0T024Ts;
  ControlVar cVar_LQ7Uy73Y;
  ControlBinop cBinop_HsLUivEO;
  ControlBinop cBinop_W2CpwBRX;
  SignalVarf sVarf_OZkm92vB;
  ControlBinop cBinop_CDCAZEC7;
  ControlBinop cBinop_i1a8rzz4;
  ControlBinop cBinop_t78OsyQW;
  SignalVarf sVarf_VypEsHX0;
  ControlVar cVar_Sb3msu5S;
  ControlVar cVar_qPswlB5N;
  ControlVar cVar_rrpl4jes;
  ControlVar cVar_dLKsQoj0;
  ControlIf cIf_wFDJExrU;
  ControlBinop cBinop_4GHJ2yjG;
  ControlBinop cBinop_6erlmA2C;
  ControlBinop cBinop_R1fMT7M4;
  ControlDelay cDelay_zpPkhuzb;
  ControlDelay cDelay_kJSspeuv;
  ControlBinop cBinop_lQZSwdxf;
  HvTable hTable_00dwCZyI;
  ControlBinop cBinop_0dJOA3GR;
  ControlTabhead cTabhead_nu3yr8jY;
  ControlVar cVar_sGVA8tu7;
  ControlDelay cDelay_bGrs1Z2t;
  ControlDelay cDelay_JkXcy9Fg;
  ControlBinop cBinop_IxOAtp6o;
  ControlBinop cBinop_O1gFRLvE;
  ControlBinop cBinop_Kb3oMvoy;
  ControlBinop cBinop_ygvDRX0h;
  ControlBinop cBinop_Tcurz7kM;
  ControlBinop cBinop_ftTNl326;
  ControlDelay cDelay_ltkTCAOk;
  ControlDelay cDelay_zqNl1EdY;
  ControlBinop cBinop_NFeE4gli;
  HvTable hTable_kiB7ZZsy;
  ControlBinop cBinop_HgcR4ASd;
  ControlTabhead cTabhead_JwAzpeA3;
  ControlVar cVar_FVZAI5He;
  ControlDelay cDelay_BZfoh41d;
  ControlDelay cDelay_TmaTojev;
  ControlBinop cBinop_UhuNsDeA;
  ControlBinop cBinop_jS6OzgyI;
  ControlBinop cBinop_DCKVMiXz;
  ControlBinop cBinop_Eaf84Jp4;
  ControlBinop cBinop_6yL9ythZ;
  ControlBinop cBinop_uaT91nnW;
  ControlDelay cDelay_AYkluoWd;
  ControlDelay cDelay_EEoNKK6V;
  ControlBinop cBinop_zBKuMnC3;
  HvTable hTable_dOOXAKYB;
  ControlBinop cBinop_CUznyTDc;
  ControlTabhead cTabhead_6JldcV9Y;
  ControlVar cVar_NWvma2sh;
  ControlDelay cDelay_JcAaMisi;
  ControlDelay cDelay_6l96BVQF;
  ControlBinop cBinop_kmEZgEYj;
  ControlBinop cBinop_yCYSkDjh;
  ControlBinop cBinop_EWesMM5f;
  ControlBinop cBinop_Z8rybyIm;
  ControlBinop cBinop_MZc5Tz2w;
  ControlBinop cBinop_GIoBNiCY;
  ControlDelay cDelay_THHfAEYq;
  ControlDelay cDelay_wCBgeqzh;
  ControlBinop cBinop_SLVDLBXC;
  HvTable hTable_u8Ki07XJ;
  ControlBinop cBinop_anIA1nsT;
  ControlTabhead cTabhead_PTyCCfqe;
  ControlVar cVar_ONIUnS9l;
  ControlDelay cDelay_KJgRwDOK;
  ControlDelay cDelay_iSYhq1ua;
  ControlBinop cBinop_chZVff0S;
  ControlBinop cBinop_RGvQbsMF;
  ControlBinop cBinop_78c2qq9a;
  ControlBinop cBinop_dS5DDe2Y;
  ControlBinop cBinop_KaZRFf8F;
  ControlBinop cBinop_nfGNihvX;
  ControlDelay cDelay_DpDEMOYZ;
  ControlDelay cDelay_30ImelmY;
  ControlBinop cBinop_91Fe4Z7x;
  HvTable hTable_rOY9kfy5;
  ControlBinop cBinop_bkIdbIOQ;
  ControlTabhead cTabhead_gMHI4n5h;
  ControlVar cVar_30oCpuNa;
  ControlDelay cDelay_UevsEoYG;
  ControlDelay cDelay_HOW6z604;
  ControlBinop cBinop_wBw3bCBP;
  ControlBinop cBinop_itL7IqNl;
  ControlBinop cBinop_SsBf06Qr;
  ControlBinop cBinop_ckd75gKN;
  ControlBinop cBinop_KxAZcFJL;
  ControlBinop cBinop_hE3NUL99;
  ControlDelay cDelay_dUnxNnXr;
  ControlDelay cDelay_tzM4CHIq;
  ControlBinop cBinop_XtIWXmTL;
  HvTable hTable_TPX2aUYJ;
  ControlBinop cBinop_OcLmNWnw;
  ControlTabhead cTabhead_vkp0pxjB;
  ControlVar cVar_ENbtR69T;
  ControlDelay cDelay_1IhddQu4;
  ControlDelay cDelay_jARMdbvI;
  ControlBinop cBinop_kqNABIh0;
  ControlBinop cBinop_IiZbv6IH;
  ControlBinop cBinop_jbQQRUar;
  ControlBinop cBinop_zgyjSQdr;
  ControlBinop cBinop_iNWI7fXK;
  ControlBinop cBinop_fkDIqTHg;
  ControlVar cVar_6FSzTCbJ;
  ControlVar cVar_GVVDrayn;
  ControlPack cPack_ZRFxjNoq;
  ControlVar cVar_JdLFrBBv;
  ControlBinop cBinop_yLa8SbA6;
  ControlBinop cBinop_3zyR2Nnr;
  SignalVarf sVarf_Py3j6gt0;
  ControlBinop cBinop_AmJGBbjZ;
  ControlBinop cBinop_el1WTBix;
  ControlBinop cBinop_mYWfDJ7D;
  SignalVarf sVarf_CacsI8l9;
  ControlVar cVar_m2VCZqqs;
  ControlBinop cBinop_IvPJbE6N;
  ControlBinop cBinop_Kzk8ugNF;
  SignalVarf sVarf_mBoQjvqh;
  ControlBinop cBinop_uXngXIHs;
  ControlBinop cBinop_cf3IASoS;
  ControlBinop cBinop_IqvgcvKt;
  SignalVarf sVarf_6hY6qzRm;
  ControlVar cVar_MVK3sVDp;
  ControlBinop cBinop_kPCJeiAP;
  ControlBinop cBinop_qlwai7tm;
  SignalVarf sVarf_MUNheMJU;
  ControlBinop cBinop_CAIRRRqC;
  ControlBinop cBinop_0T8n6JdQ;
  ControlBinop cBinop_7FsFGWTQ;
  SignalVarf sVarf_o9jWtfAP;
  ControlBinop cBinop_cktvigB2;
  ControlBinop cBinop_Q4IxNzNq;
  ControlBinop cBinop_iblLCVTP;
  ControlDelay cDelay_cFYsL34s;
  ControlVar cVar_SmUxTTYk;
  ControlBinop cBinop_j4rEFGsB;
  ControlBinop cBinop_EGrGjqjC;
  ControlBinop cBinop_7PgJGQ1v;
  ControlVar cVar_jN7qYR6X;
  ControlVar cVar_mL7d4R82;
  ControlIf cIf_3vkpVd19;
  ControlBinop cBinop_J0WGoSv6;
  ControlDelay cDelay_y0VvwmZa;
  ControlDelay cDelay_LHnv6lY2;
  ControlBinop cBinop_eKsJDMgp;
  HvTable hTable_pL6tXkvh;
  ControlBinop cBinop_qgSuf1Eh;
  ControlTabhead cTabhead_QcoDdV1h;
  ControlVar cVar_mDpUoG2T;
  ControlDelay cDelay_0Bhw2Y1Y;
  ControlDelay cDelay_RJp18UEI;
  ControlBinop cBinop_XydBZroK;
  ControlBinop cBinop_s8rhR9mf;
  ControlBinop cBinop_B2dz2tW0;
  ControlBinop cBinop_KPLa4LXN;
  ControlBinop cBinop_Qyd9y177;
  ControlBinop cBinop_ioKPWgCh;
  ControlVar cVar_kPquj3oT;
  ControlVar cVar_OBTS3FgY;
  ControlVar cVar_4PDJSD6t;
  ControlVar cVar_CC7o3Nrx;
  ControlVar cVar_jVyfnYoZ;
  ControlVar cVar_ydJzJNsf;
  ControlIf cIf_xPHgj3KT;
  ControlBinop cBinop_zl5iAOnC;
  ControlVar cVar_7xTWCzNT;
  ControlIf cIf_kLcuxDza;
  ControlBinop cBinop_5S9bRQj0;
  ControlSlice cSlice_IVEnlmFj;
  ControlSlice cSlice_OUrAoUFp;
  ControlVar cVar_q21putqw;
  ControlIf cIf_lKgjFa6Q;
  ControlBinop cBinop_N4pFfGdH;
  ControlIf cIf_0JuNAvFq;
  ControlIf cIf_LYdjdLWW;
  ControlIf cIf_O9lkr9Ts;
  ControlIf cIf_nf8Sp4Ar;
  ControlIf cIf_k08280IG;
  SignalVarf sVarf_zm8AM6oN;
  ControlBinop cBinop_Ir11yASN;
  ControlBinop cBinop_JTztm6B4;
  ControlBinop cBinop_3RCwtewE;
  ControlBinop cBinop_qbtuQ1Dz;
  SignalVarf sVarf_gTcKVELl;
  ControlBinop cBinop_A8zgVzRX;
  ControlBinop cBinop_PLOTSogW;
  SignalVarf sVarf_3Agh9jvP;
  SignalVarf sVarf_3MBS3tvK;
  ControlBinop cBinop_WJNHyY4i;
  ControlBinop cBinop_lMCeR05l;
  ControlBinop cBinop_diBUbZde;
  ControlBinop cBinop_oYWCPpCy;
  ControlBinop cBinop_5T8aoSIY;
  ControlBinop cBinop_iuW79QQq;
  ControlBinop cBinop_hs1W8hnR;
  ControlBinop cBinop_wtSoDNbN;
  ControlBinop cBinop_xyxw7h7R;
  ControlBinop cBinop_YItALXs2;
  ControlBinop cBinop_Fzbz7QoV;
  ControlBinop cBinop_Gx5Jbbj6;
  ControlBinop cBinop_gjtnYbeE;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
