/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_ppRcYNGN, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_lch0oisU);
  numBytes += sLine_init(&sLine_Tvq6peL0);
  numBytes += sTabhead_init(&sTabhead_wEIul4rI, &hTable_slYmAgul);
  numBytes += sTabread_init(&sTabread_4lq60lga, &hTable_slYmAgul, false);
  numBytes += sTabread_init(&sTabread_VT0SnUzQ, &hTable_slYmAgul, false);
  numBytes += sTabhead_init(&sTabhead_8xJKFYgk, &hTable_slYmAgul);
  numBytes += sTabread_init(&sTabread_jikl2ZIm, &hTable_slYmAgul, false);
  numBytes += sTabread_init(&sTabread_YuN3e68Q, &hTable_slYmAgul, false);
  numBytes += sTabwrite_init(&sTabwrite_l0v3pjVv, &hTable_slYmAgul);
  numBytes += sRPole_init(&sRPole_sJDesaqr);
  numBytes += sDel1_init(&sDel1_xtJFhx0L);
  numBytes += sTabread_init(&sTabread_8CL64JUv, &hTable_pL6tXkvh, true);
  numBytes += sTabwrite_init(&sTabwrite_Gi2itpse, &hTable_pL6tXkvh);
  numBytes += sTabread_init(&sTabread_UoQ0vKCA, &hTable_WrDyEsyh, true);
  numBytes += sRPole_init(&sRPole_JzAlQyH5);
  numBytes += sLine_init(&sLine_dAYgHCK0);
  numBytes += sLine_init(&sLine_xanK1odK);
  numBytes += sTabread_init(&sTabread_k9qNzWUH, &hTable_00dwCZyI, true);
  numBytes += sTabread_init(&sTabread_ND6Qevho, &hTable_kiB7ZZsy, true);
  numBytes += sTabread_init(&sTabread_lpoU3cAm, &hTable_dOOXAKYB, true);
  numBytes += sTabread_init(&sTabread_ty0k8Ros, &hTable_u8Ki07XJ, true);
  numBytes += sTabread_init(&sTabread_xkzta5HU, &hTable_TPX2aUYJ, true);
  numBytes += sTabread_init(&sTabread_Uhcv57ms, &hTable_rOY9kfy5, true);
  numBytes += sTabwrite_init(&sTabwrite_ClZu3Zl9, &hTable_00dwCZyI);
  numBytes += sTabwrite_init(&sTabwrite_3hr2lOhj, &hTable_kiB7ZZsy);
  numBytes += sTabwrite_init(&sTabwrite_T6lcn9rJ, &hTable_dOOXAKYB);
  numBytes += sTabwrite_init(&sTabwrite_ETw3W8dB, &hTable_u8Ki07XJ);
  numBytes += sTabwrite_init(&sTabwrite_lc4Ag43H, &hTable_rOY9kfy5);
  numBytes += sTabwrite_init(&sTabwrite_r7FOShdG, &hTable_TPX2aUYJ);
  numBytes += sTabread_init(&sTabread_S7xJkpS3, &hTable_zVxuWmbl, true);
  numBytes += sRPole_init(&sRPole_9iABMgkg);
  numBytes += sTabread_init(&sTabread_x0pWAuRM, &hTable_glpRfysY, true);
  numBytes += sRPole_init(&sRPole_VuLQRRTZ);
  numBytes += sTabread_init(&sTabread_ttPuCrK9, &hTable_4XUDdaNR, true);
  numBytes += sRPole_init(&sRPole_m9O1ThvH);
  numBytes += sTabwrite_init(&sTabwrite_eErH9xec, &hTable_WrDyEsyh);
  numBytes += sTabwrite_init(&sTabwrite_J9IhJjcq, &hTable_zVxuWmbl);
  numBytes += sTabwrite_init(&sTabwrite_B4ISYUzw, &hTable_glpRfysY);
  numBytes += sTabwrite_init(&sTabwrite_RlipCkZz, &hTable_4XUDdaNR);
  numBytes += sLine_init(&sLine_rzfDCGjt);
  numBytes += cVar_init_f(&cVar_0yBYa0wm, 0.0f);
  numBytes += cVar_init_f(&cVar_XFEgbzvp, 0.0f);
  numBytes += cPack_init(&cPack_5QkQiPNQ, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_z3zlV9GE, 0.0f);
  numBytes += cPack_init(&cPack_0IABOYzF, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_qYCweP8T, 0.0f);
  numBytes += cVar_init_f(&cVar_zONIJThz, 0.0f);
  numBytes += cDelay_init(this, &cDelay_V73pJ6pf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xsO59CT6, 0.0f);
  numBytes += hTable_init(&hTable_slYmAgul, 256);
  numBytes += cVar_init_s(&cVar_lO0N0vfP, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_QtIL0rn0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XS4FGTD5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0UvsKo7Z, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_3jFLkH1g, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_3kmzPTfP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6K12GXX9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cdZWQDfu, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_eoSKZGeN, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_8ast95bf, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_nSbWqOgd, 0.0f);
  numBytes += cBinop_init(&cBinop_i445Vj5U, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Mx6fcBx8, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_wlLhYcC2, -1557562060);
  numBytes += cSlice_init(&cSlice_vRKjOgr6, 1, 1);
  numBytes += cDelay_init(this, &cDelay_7acqyRqu, 0.0f);
  numBytes += cVar_init_f(&cVar_iZViNGBn, 5.0f);
  numBytes += cBinop_init(&cBinop_aSrOEwuE, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_MGwj9Nid, &hTable_WrDyEsyh);
  numBytes += cVar_init_s(&cVar_Ln8eloxK, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_PoZef20Y, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_xKxzvcC6, 0.0f);
  numBytes += cBinop_init(&cBinop_Zg3aum4N, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_8Aq9UeSb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_VotZOmbY, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_f3f69OGM, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_ht8yPDP4, &hTable_zVxuWmbl);
  numBytes += cVar_init_s(&cVar_f4QIigP8, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_IN88dgW6, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_3DyCHv6C, 0.0f);
  numBytes += cBinop_init(&cBinop_byTNMob1, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_1Y3ZiPNl, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_kun3ViuV, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_n6UwA2tu, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_9LPq23HG, &hTable_glpRfysY);
  numBytes += cVar_init_s(&cVar_IdzeTBDq, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_ykD40xTi, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_kVRJgQJa, 0.0f);
  numBytes += cBinop_init(&cBinop_Ohhmieb3, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_01FQ8edb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_H8q7VqaS, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_UYpJDZ64, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_A0aSLEpF, &hTable_4XUDdaNR);
  numBytes += cVar_init_s(&cVar_3veFdNr4, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_fkhg2ba4, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_KYs1Yfuj, 0.0f);
  numBytes += cBinop_init(&cBinop_CTHILY71, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_t6XGvMSv, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_eAveW25X, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_y3J8tzcj, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_1QiNPfk8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_QF8BX84V, 0.0f);
  numBytes += hTable_init(&hTable_WrDyEsyh, 256);
  numBytes += cDelay_init(this, &cDelay_SRCzwI6K, 0.0f);
  numBytes += cDelay_init(this, &cDelay_M1kVQ2CK, 0.0f);
  numBytes += hTable_init(&hTable_zVxuWmbl, 256);
  numBytes += cDelay_init(this, &cDelay_za2DeifV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_HyZbH4Cs, 0.0f);
  numBytes += hTable_init(&hTable_glpRfysY, 256);
  numBytes += cDelay_init(this, &cDelay_td6dYAEJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_S9sVtf8h, 0.0f);
  numBytes += hTable_init(&hTable_4XUDdaNR, 256);
  numBytes += cPack_init(&cPack_sslaJDLL, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_i3VtgeCa, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_LQ7Uy73Y, 22050.0f);
  numBytes += cBinop_init(&cBinop_HsLUivEO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_OZkm92vB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VypEsHX0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Sb3msu5S, 0.0f);
  numBytes += cVar_init_f(&cVar_qPswlB5N, 0.0f);
  numBytes += cVar_init_f(&cVar_rrpl4jes, 0.0f);
  numBytes += cVar_init_f(&cVar_dLKsQoj0, 0.0f);
  numBytes += cIf_init(&cIf_wFDJExrU, false);
  numBytes += cDelay_init(this, &cDelay_zpPkhuzb, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kJSspeuv, 0.0f);
  numBytes += hTable_init(&hTable_00dwCZyI, 256);
  numBytes += cTabhead_init(&cTabhead_nu3yr8jY, &hTable_00dwCZyI);
  numBytes += cVar_init_s(&cVar_sGVA8tu7, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_bGrs1Z2t, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_JkXcy9Fg, 0.0f);
  numBytes += cBinop_init(&cBinop_IxOAtp6o, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_Kb3oMvoy, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ygvDRX0h, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ftTNl326, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_ltkTCAOk, 0.0f);
  numBytes += cDelay_init(this, &cDelay_zqNl1EdY, 0.0f);
  numBytes += hTable_init(&hTable_kiB7ZZsy, 256);
  numBytes += cTabhead_init(&cTabhead_JwAzpeA3, &hTable_kiB7ZZsy);
  numBytes += cVar_init_s(&cVar_FVZAI5He, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_BZfoh41d, 25.796f);
  numBytes += cDelay_init(this, &cDelay_TmaTojev, 0.0f);
  numBytes += cBinop_init(&cBinop_UhuNsDeA, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_DCKVMiXz, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Eaf84Jp4, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_uaT91nnW, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_AYkluoWd, 0.0f);
  numBytes += cDelay_init(this, &cDelay_EEoNKK6V, 0.0f);
  numBytes += hTable_init(&hTable_dOOXAKYB, 256);
  numBytes += cTabhead_init(&cTabhead_6JldcV9Y, &hTable_dOOXAKYB);
  numBytes += cVar_init_s(&cVar_NWvma2sh, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_JcAaMisi, 19.392f);
  numBytes += cDelay_init(this, &cDelay_6l96BVQF, 0.0f);
  numBytes += cBinop_init(&cBinop_kmEZgEYj, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_EWesMM5f, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Z8rybyIm, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GIoBNiCY, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_THHfAEYq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wCBgeqzh, 0.0f);
  numBytes += hTable_init(&hTable_u8Ki07XJ, 256);
  numBytes += cTabhead_init(&cTabhead_PTyCCfqe, &hTable_u8Ki07XJ);
  numBytes += cVar_init_s(&cVar_ONIUnS9l, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_KJgRwDOK, 16.364f);
  numBytes += cDelay_init(this, &cDelay_iSYhq1ua, 0.0f);
  numBytes += cBinop_init(&cBinop_chZVff0S, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_78c2qq9a, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_dS5DDe2Y, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_nfGNihvX, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_DpDEMOYZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_30ImelmY, 0.0f);
  numBytes += hTable_init(&hTable_rOY9kfy5, 256);
  numBytes += cTabhead_init(&cTabhead_gMHI4n5h, &hTable_rOY9kfy5);
  numBytes += cVar_init_s(&cVar_30oCpuNa, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_UevsEoYG, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_HOW6z604, 0.0f);
  numBytes += cBinop_init(&cBinop_wBw3bCBP, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_SsBf06Qr, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ckd75gKN, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_hE3NUL99, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_dUnxNnXr, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tzM4CHIq, 0.0f);
  numBytes += hTable_init(&hTable_TPX2aUYJ, 256);
  numBytes += cTabhead_init(&cTabhead_vkp0pxjB, &hTable_TPX2aUYJ);
  numBytes += cVar_init_s(&cVar_ENbtR69T, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_1IhddQu4, 7.645f);
  numBytes += cDelay_init(this, &cDelay_jARMdbvI, 0.0f);
  numBytes += cBinop_init(&cBinop_kqNABIh0, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_jbQQRUar, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_zgyjSQdr, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_fkDIqTHg, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_6FSzTCbJ, 0.0f);
  numBytes += cVar_init_f(&cVar_GVVDrayn, 0.0f);
  numBytes += cPack_init(&cPack_ZRFxjNoq, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_JdLFrBBv, 22050.0f);
  numBytes += cBinop_init(&cBinop_yLa8SbA6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Py3j6gt0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CacsI8l9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_m2VCZqqs, 22050.0f);
  numBytes += cBinop_init(&cBinop_IvPJbE6N, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mBoQjvqh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6hY6qzRm, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MVK3sVDp, 22050.0f);
  numBytes += cBinop_init(&cBinop_kPCJeiAP, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_MUNheMJU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o9jWtfAP, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_cFYsL34s, 0.0f);
  numBytes += cVar_init_f(&cVar_SmUxTTYk, 1000.0f);
  numBytes += cBinop_init(&cBinop_7PgJGQ1v, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_jN7qYR6X, 0.0f);
  numBytes += cVar_init_f(&cVar_mL7d4R82, 0.0f);
  numBytes += cIf_init(&cIf_3vkpVd19, false);
  numBytes += cDelay_init(this, &cDelay_y0VvwmZa, 0.0f);
  numBytes += cDelay_init(this, &cDelay_LHnv6lY2, 0.0f);
  numBytes += hTable_init(&hTable_pL6tXkvh, 256);
  numBytes += cTabhead_init(&cTabhead_QcoDdV1h, &hTable_pL6tXkvh);
  numBytes += cVar_init_s(&cVar_mDpUoG2T, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_0Bhw2Y1Y, 150.0f);
  numBytes += cDelay_init(this, &cDelay_RJp18UEI, 0.0f);
  numBytes += cBinop_init(&cBinop_XydBZroK, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_B2dz2tW0, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_KPLa4LXN, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ioKPWgCh, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_kPquj3oT, 0.0f);
  numBytes += cVar_init_f(&cVar_OBTS3FgY, 0.0f);
  numBytes += cVar_init_f(&cVar_4PDJSD6t, 0.0f);
  numBytes += cVar_init_f(&cVar_CC7o3Nrx, 0.0f);
  numBytes += cVar_init_f(&cVar_jVyfnYoZ, 0.0f);
  numBytes += cVar_init_f(&cVar_ydJzJNsf, 0.0f);
  numBytes += cIf_init(&cIf_xPHgj3KT, false);
  numBytes += cVar_init_f(&cVar_7xTWCzNT, 0.0f);
  numBytes += cIf_init(&cIf_kLcuxDza, false);
  numBytes += cSlice_init(&cSlice_IVEnlmFj, 1, -1);
  numBytes += cSlice_init(&cSlice_OUrAoUFp, 1, -1);
  numBytes += cVar_init_f(&cVar_q21putqw, 0.0f);
  numBytes += cIf_init(&cIf_lKgjFa6Q, false);
  numBytes += cBinop_init(&cBinop_N4pFfGdH, 0.0f); // __neq
  numBytes += cIf_init(&cIf_0JuNAvFq, false);
  numBytes += cIf_init(&cIf_LYdjdLWW, false);
  numBytes += cIf_init(&cIf_O9lkr9Ts, false);
  numBytes += cIf_init(&cIf_nf8Sp4Ar, true);
  numBytes += cIf_init(&cIf_k08280IG, false);
  numBytes += sVarf_init(&sVarf_zm8AM6oN, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_3RCwtewE, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_gTcKVELl, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_A8zgVzRX, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_PLOTSogW, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_3Agh9jvP, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3MBS3tvK, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_lMCeR05l, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_xyxw7h7R, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YItALXs2, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_Fzbz7QoV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Gx5Jbbj6, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_gjtnYbeE, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_5QkQiPNQ);
  cPack_free(&cPack_0IABOYzF);
  hTable_free(&hTable_slYmAgul);
  hTable_free(&hTable_WrDyEsyh);
  hTable_free(&hTable_zVxuWmbl);
  hTable_free(&hTable_glpRfysY);
  hTable_free(&hTable_4XUDdaNR);
  cPack_free(&cPack_sslaJDLL);
  cPack_free(&cPack_i3VtgeCa);
  hTable_free(&hTable_00dwCZyI);
  hTable_free(&hTable_kiB7ZZsy);
  hTable_free(&hTable_dOOXAKYB);
  hTable_free(&hTable_u8Ki07XJ);
  hTable_free(&hTable_rOY9kfy5);
  hTable_free(&hTable_TPX2aUYJ);
  cPack_free(&cPack_ZRFxjNoq);
  hTable_free(&hTable_pL6tXkvh);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_slYmAgul; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_WrDyEsyh; // del-1052-del1
    case 0xA2AC524D: return &hTable_zVxuWmbl; // del-1052-del2
    case 0xE36A35B: return &hTable_glpRfysY; // del-1052-del3
    case 0x48CE0509: return &hTable_4XUDdaNR; // del-1052-del4
    case 0xE34D6E72: return &hTable_00dwCZyI; // del-1052-ref1
    case 0x6A1027AB: return &hTable_kiB7ZZsy; // del-1052-ref2
    case 0xA37C6D49: return &hTable_dOOXAKYB; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_u8Ki07XJ; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_rOY9kfy5; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_TPX2aUYJ; // del-1052-ref5
    case 0xED65564F: return &hTable_pL6tXkvh; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pzpSrTyl_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kwa9qNLu_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7WLPvbdj_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yrwicUs7_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X6Dwjhd4_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YrYP88Yv_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BGvFqjmk_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tFUwdQsc_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kS2iQooj_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4ntEUaj9_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tv8SeIkk_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gh1y0I3l_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_caG62iMB_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2xfLWu1n_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jqRzHgu7_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FiXPPwnN_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rNd5C1Hx_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3Wmc3ZMK_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fUynZdpu_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_91uMFuBS_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eXz4z9oQ_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oTo5enLY_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_en8K2huC_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aUab1fDm_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_0yBYa0wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_ks2XFugz_sendMessage);
}

void Heavy_ChaffVerb::cVar_XFEgbzvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_h1KliAMI_sendMessage);
}

void Heavy_ChaffVerb::cPack_5QkQiPNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_lch0oisU, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_a1WOw0RL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z3zlV9GE, 0, m, &cVar_z3zlV9GE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_d3cICdEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_a1WOw0RL_sendMessage);
}

void Heavy_ChaffVerb::cVar_z3zlV9GE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GnNwPjAy_sendMessage);
}

void Heavy_ChaffVerb::cPack_0IABOYzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_Tvq6peL0, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_qYCweP8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_BsEAYlrQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_zONIJThz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_ppRcYNGN, 0, m);
}

void Heavy_ChaffVerb::cMsg_QavO5ehE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SRTKOlGj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SRTKOlGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WZbF8muB_sendMessage);
}

void Heavy_ChaffVerb::cDelay_V73pJ6pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V73pJ6pf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xsO59CT6, 0, m, &cDelay_xsO59CT6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_V73pJ6pf, 0, m, &cDelay_V73pJ6pf_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_l0v3pjVv, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_xsO59CT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xsO59CT6, m);
  cMsg_SdLPxQIH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_0nvxcqi6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Dommpvsx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_IU73MOyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i1cTH0Mh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_slYmAgul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKYtj20t_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_V73pJ6pf, 2, m, &cDelay_V73pJ6pf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xLbs3yKz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_i1cTH0Mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_slYmAgul, 0, m, &hTable_slYmAgul_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WZbF8muB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_IU73MOyc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SdLPxQIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_slYmAgul, 0, m, &hTable_slYmAgul_sendMessage);
}

void Heavy_ChaffVerb::cCast_xLbs3yKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_V73pJ6pf, 0, m, &cDelay_V73pJ6pf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RKYtj20t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xsO59CT6, 2, m, &cDelay_xsO59CT6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Dommpvsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_l0v3pjVv, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_mKa4R9Ra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lBRSZ2GU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lBRSZ2GU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QDlHgl1Y_sendMessage);
}

void Heavy_ChaffVerb::cVar_lO0N0vfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9JbwkoMZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_cT8i3V6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3D0RW3Xb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QtIL0rn0, m);
}

void Heavy_ChaffVerb::cBinop_QDlHgl1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XS4FGTD5, m);
}

void Heavy_ChaffVerb::cMsg_9JbwkoMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cT8i3V6N_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3D0RW3Xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0UvsKo7Z, m);
}

void Heavy_ChaffVerb::cMsg_m8A4XvIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_x5U6svqQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_x5U6svqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7J6yD3Fu_sendMessage);
}

void Heavy_ChaffVerb::cVar_3jFLkH1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OwXHDHJF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_oM6zmVXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mVPRA0O2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3kmzPTfP, m);
}

void Heavy_ChaffVerb::cBinop_7J6yD3Fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6K12GXX9, m);
}

void Heavy_ChaffVerb::cMsg_OwXHDHJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oM6zmVXu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mVPRA0O2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cdZWQDfu, m);
}

void Heavy_ChaffVerb::cBinop_eoSKZGeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zONIJThz, 0, m, &cVar_zONIJThz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zg1qVRtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5HPw8Dqf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GqbMohzp_sendMessage);
}

void Heavy_ChaffVerb::cCast_5HPw8Dqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eoSKZGeN, HV_BINOP_DIVIDE, 1, m, &cBinop_eoSKZGeN_sendMessage);
}

void Heavy_ChaffVerb::cCast_GqbMohzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eoSKZGeN, HV_BINOP_DIVIDE, 0, m, &cBinop_eoSKZGeN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GnNwPjAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qjYBCf34_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ks2XFugz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_d3cICdEa_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qjYBCf34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eoSKZGeN, HV_BINOP_DIVIDE, 0, m, &cBinop_eoSKZGeN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BsEAYlrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_0IABOYzF, 0, m, &cPack_0IABOYzF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h1KliAMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_Zg1qVRtQ_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_5QkQiPNQ, 0, m, &cPack_5QkQiPNQ_sendMessage);
}

void Heavy_ChaffVerb::cUnop_NOZXvnJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LYdjdLWW, 0, m, &cIf_LYdjdLWW_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_jZhI0fvY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jMtUtmHX_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VHoh7U9C_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LaW8Qpe4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_jMtUtmHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8o7BFj5N_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_VHoh7U9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mjxu2Yqc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_LaW8Qpe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UQ9P5d6A_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_sDDQieiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wthftv84_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wthftv84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qt1Oou1v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Bun04vPA_sendMessage);
}

void Heavy_ChaffVerb::cVar_nSbWqOgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_f1UoLbwG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0F9EVmSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JP21U8sO_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JP21U8sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i445Vj5U, HV_BINOP_DIVIDE, 1, m, &cBinop_i445Vj5U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qt1Oou1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4M1yo1gi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4M1yo1gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Mx6fcBx8, m);
}

void Heavy_ChaffVerb::cMsg_Gd6UmXBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_J1pdm4dQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_J1pdm4dQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sDDQieiw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Bun04vPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8ast95bf, m);
}

void Heavy_ChaffVerb::cBinop_f1UoLbwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_bJGs6acw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bJGs6acw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i445Vj5U, HV_BINOP_DIVIDE, 0, m, &cBinop_i445Vj5U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_i445Vj5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gd6UmXBa_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_W4T1IVgY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vRKjOgr6, 0, m, &cSlice_vRKjOgr6_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_wlLhYcC2, 0, m, &cRandom_wlLhYcC2_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_1VjimSbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_Dv3QbVfu_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Dv3QbVfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_JTztm6B4_sendMessage);
}

void Heavy_ChaffVerb::cRandom_wlLhYcC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_1VjimSbv_sendMessage);
}

void Heavy_ChaffVerb::cSlice_vRKjOgr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_wlLhYcC2, 1, m, &cRandom_wlLhYcC2_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_UOPM5CAn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_HtqDEYzm_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_HtqDEYzm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JVg9hkks_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_7acqyRqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7acqyRqu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7acqyRqu, 0, m, &cDelay_7acqyRqu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jN7qYR6X, 0, m, &cVar_jN7qYR6X_sendMessage);
}

void Heavy_ChaffVerb::cCast_JVg9hkks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HtqDEYzm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7acqyRqu, 0, m, &cDelay_7acqyRqu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jN7qYR6X, 0, m, &cVar_jN7qYR6X_sendMessage);
}

void Heavy_ChaffVerb::cMsg_62V7fRcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_09s8WICu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_09s8WICu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1I59E94h_sendMessage);
}

void Heavy_ChaffVerb::cVar_iZViNGBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aSrOEwuE, HV_BINOP_MULTIPLY, 0, m, &cBinop_aSrOEwuE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HtqDEYzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7acqyRqu, 0, m, &cDelay_7acqyRqu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_14K7k8r9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7acqyRqu, 2, m, &cDelay_7acqyRqu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1I59E94h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aSrOEwuE, HV_BINOP_MULTIPLY, 1, m, &cBinop_aSrOEwuE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aSrOEwuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_14K7k8r9_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_MGwj9Nid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Aq9UeSb, HV_BINOP_SUBTRACT, 0, m, &cBinop_8Aq9UeSb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qj7AC8tQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_t2zYROFV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_t2zYROFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qsQXsOI1_sendMessage);
}

void Heavy_ChaffVerb::cVar_Ln8eloxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RoIE8UIg_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_PoZef20Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PoZef20Y, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xKxzvcC6, 0, m, &cDelay_xKxzvcC6_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UoQ0vKCA, 0, m, &sTabread_UoQ0vKCA_sendMessage);
}

void Heavy_ChaffVerb::cDelay_xKxzvcC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xKxzvcC6, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UoQ0vKCA, 0, m, &sTabread_UoQ0vKCA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xKxzvcC6, 0, m, &cDelay_xKxzvcC6_sendMessage);
}

void Heavy_ChaffVerb::sTabread_UoQ0vKCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_f3f69OGM, HV_BINOP_SUBTRACT, 0, m, &cBinop_f3f69OGM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Zg3aum4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VotZOmbY, HV_BINOP_MAX, 0, m, &cBinop_VotZOmbY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qsQXsOI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zg3aum4N, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zg3aum4N_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8Aq9UeSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F3BEWI9C_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UoQ0vKCA, 0, m, &sTabread_UoQ0vKCA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k1GxmaqR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_6WaYni3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f3f69OGM, HV_BINOP_SUBTRACT, 1, m, &cBinop_f3f69OGM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xKxzvcC6, 2, m, &cDelay_xKxzvcC6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RoIE8UIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6WaYni3D_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F3BEWI9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PoZef20Y, 0, m, &cDelay_PoZef20Y_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xKxzvcC6, 0, m, &cDelay_xKxzvcC6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XIaSgd3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_VotZOmbY, HV_BINOP_MAX, 1, m, &cBinop_VotZOmbY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VotZOmbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Aq9UeSb, HV_BINOP_SUBTRACT, 1, m, &cBinop_8Aq9UeSb_sendMessage);
}

void Heavy_ChaffVerb::cCast_k1GxmaqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PoZef20Y, 0, m, &cDelay_PoZef20Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YRQHhvpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PoZef20Y, 2, m, &cDelay_PoZef20Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_f3f69OGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YRQHhvpp_sendMessage);
}

void Heavy_ChaffVerb::cCast_wPEfOQG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ln8eloxK, 0, m, &cVar_Ln8eloxK_sendMessage);
  cMsg_qj7AC8tQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MGwj9Nid, 0, m, &cTabhead_MGwj9Nid_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_ht8yPDP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Y3ZiPNl, HV_BINOP_SUBTRACT, 0, m, &cBinop_1Y3ZiPNl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VbLG2YRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f24J1qym_sendMessage);
}

void Heavy_ChaffVerb::cSystem_f24J1qym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_P0pSzGhL_sendMessage);
}

void Heavy_ChaffVerb::cVar_f4QIigP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MQUotpiD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_IN88dgW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IN88dgW6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3DyCHv6C, 0, m, &cDelay_3DyCHv6C_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_S7xJkpS3, 0, m, &sTabread_S7xJkpS3_sendMessage);
}

void Heavy_ChaffVerb::cDelay_3DyCHv6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3DyCHv6C, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_S7xJkpS3, 0, m, &sTabread_S7xJkpS3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3DyCHv6C, 0, m, &cDelay_3DyCHv6C_sendMessage);
}

void Heavy_ChaffVerb::sTabread_S7xJkpS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_n6UwA2tu, HV_BINOP_SUBTRACT, 0, m, &cBinop_n6UwA2tu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_byTNMob1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kun3ViuV, HV_BINOP_MAX, 0, m, &cBinop_kun3ViuV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_P0pSzGhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_byTNMob1, HV_BINOP_MULTIPLY, 0, m, &cBinop_byTNMob1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1Y3ZiPNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_shjreKhs_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_S7xJkpS3, 0, m, &sTabread_S7xJkpS3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HT4fWIKy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_BSqfBQrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n6UwA2tu, HV_BINOP_SUBTRACT, 1, m, &cBinop_n6UwA2tu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3DyCHv6C, 2, m, &cDelay_3DyCHv6C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MQUotpiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BSqfBQrO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_shjreKhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IN88dgW6, 0, m, &cDelay_IN88dgW6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3DyCHv6C, 0, m, &cDelay_3DyCHv6C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cH7ShmiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_kun3ViuV, HV_BINOP_MAX, 1, m, &cBinop_kun3ViuV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kun3ViuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Y3ZiPNl, HV_BINOP_SUBTRACT, 1, m, &cBinop_1Y3ZiPNl_sendMessage);
}

void Heavy_ChaffVerb::cCast_HT4fWIKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IN88dgW6, 0, m, &cDelay_IN88dgW6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_numAV2Fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IN88dgW6, 2, m, &cDelay_IN88dgW6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_n6UwA2tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_numAV2Fc_sendMessage);
}

void Heavy_ChaffVerb::cCast_3p3IugjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f4QIigP8, 0, m, &cVar_f4QIigP8_sendMessage);
  cMsg_VbLG2YRU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ht8yPDP4, 0, m, &cTabhead_ht8yPDP4_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_9LPq23HG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_01FQ8edb, HV_BINOP_SUBTRACT, 0, m, &cBinop_01FQ8edb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6zNeq73S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JweFN5gl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JweFN5gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Z25tBp4L_sendMessage);
}

void Heavy_ChaffVerb::cVar_IdzeTBDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NPTV2RRc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ykD40xTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ykD40xTi, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVRJgQJa, 0, m, &cDelay_kVRJgQJa_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x0pWAuRM, 0, m, &sTabread_x0pWAuRM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_kVRJgQJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kVRJgQJa, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x0pWAuRM, 0, m, &sTabread_x0pWAuRM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVRJgQJa, 0, m, &cDelay_kVRJgQJa_sendMessage);
}

void Heavy_ChaffVerb::sTabread_x0pWAuRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_UYpJDZ64, HV_BINOP_SUBTRACT, 0, m, &cBinop_UYpJDZ64_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Ohhmieb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H8q7VqaS, HV_BINOP_MAX, 0, m, &cBinop_H8q7VqaS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Z25tBp4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ohhmieb3, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ohhmieb3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_01FQ8edb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mqwdfxL9_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x0pWAuRM, 0, m, &sTabread_x0pWAuRM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cozk6cZq_sendMessage);
}

void Heavy_ChaffVerb::cSystem_WM3MFVqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYpJDZ64, HV_BINOP_SUBTRACT, 1, m, &cBinop_UYpJDZ64_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVRJgQJa, 2, m, &cDelay_kVRJgQJa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NPTV2RRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WM3MFVqJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mqwdfxL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ykD40xTi, 0, m, &cDelay_ykD40xTi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVRJgQJa, 0, m, &cDelay_kVRJgQJa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tiCfMp5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_H8q7VqaS, HV_BINOP_MAX, 1, m, &cBinop_H8q7VqaS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_H8q7VqaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_01FQ8edb, HV_BINOP_SUBTRACT, 1, m, &cBinop_01FQ8edb_sendMessage);
}

void Heavy_ChaffVerb::cCast_Cozk6cZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ykD40xTi, 0, m, &cDelay_ykD40xTi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jVNB2V8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ykD40xTi, 2, m, &cDelay_ykD40xTi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UYpJDZ64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jVNB2V8K_sendMessage);
}

void Heavy_ChaffVerb::cCast_ObJxhqln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IdzeTBDq, 0, m, &cVar_IdzeTBDq_sendMessage);
  cMsg_6zNeq73S_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_9LPq23HG, 0, m, &cTabhead_9LPq23HG_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_A0aSLEpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t6XGvMSv, HV_BINOP_SUBTRACT, 0, m, &cBinop_t6XGvMSv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_g5sgzVUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AOLHTHVT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AOLHTHVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pn46GA8U_sendMessage);
}

void Heavy_ChaffVerb::cVar_3veFdNr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m5J0VDri_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_fkhg2ba4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fkhg2ba4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KYs1Yfuj, 0, m, &cDelay_KYs1Yfuj_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ttPuCrK9, 0, m, &sTabread_ttPuCrK9_sendMessage);
}

void Heavy_ChaffVerb::cDelay_KYs1Yfuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KYs1Yfuj, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ttPuCrK9, 0, m, &sTabread_ttPuCrK9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KYs1Yfuj, 0, m, &cDelay_KYs1Yfuj_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ttPuCrK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_y3J8tzcj, HV_BINOP_SUBTRACT, 0, m, &cBinop_y3J8tzcj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_CTHILY71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eAveW25X, HV_BINOP_MAX, 0, m, &cBinop_eAveW25X_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pn46GA8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CTHILY71, HV_BINOP_MULTIPLY, 0, m, &cBinop_CTHILY71_sendMessage);
}

void Heavy_ChaffVerb::cBinop_t6XGvMSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_38MAjBAv_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ttPuCrK9, 0, m, &sTabread_ttPuCrK9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p3UdnH4K_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qXO2yqZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y3J8tzcj, HV_BINOP_SUBTRACT, 1, m, &cBinop_y3J8tzcj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KYs1Yfuj, 2, m, &cDelay_KYs1Yfuj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m5J0VDri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qXO2yqZN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_38MAjBAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fkhg2ba4, 0, m, &cDelay_fkhg2ba4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KYs1Yfuj, 0, m, &cDelay_KYs1Yfuj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FC2HBuZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_eAveW25X, HV_BINOP_MAX, 1, m, &cBinop_eAveW25X_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eAveW25X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t6XGvMSv, HV_BINOP_SUBTRACT, 1, m, &cBinop_t6XGvMSv_sendMessage);
}

void Heavy_ChaffVerb::cCast_p3UdnH4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fkhg2ba4, 0, m, &cDelay_fkhg2ba4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yc1mkSLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fkhg2ba4, 2, m, &cDelay_fkhg2ba4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y3J8tzcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yc1mkSLk_sendMessage);
}

void Heavy_ChaffVerb::cCast_4W5d7CRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3veFdNr4, 0, m, &cVar_3veFdNr4_sendMessage);
  cMsg_g5sgzVUF_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_A0aSLEpF, 0, m, &cTabhead_A0aSLEpF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BCDiCQz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8VtKrvIi_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8VtKrvIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_s9aNCpAO_sendMessage);
}

void Heavy_ChaffVerb::cDelay_1QiNPfk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1QiNPfk8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QF8BX84V, 0, m, &cDelay_QF8BX84V_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QiNPfk8, 0, m, &cDelay_1QiNPfk8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eErH9xec, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_QF8BX84V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QF8BX84V, m);
  cMsg_iO8ZBx9q_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_R2IQhoY2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_oZtW7ZmG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Oi0yljSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JokX5uOb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_WrDyEsyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RXPU2zkE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QiNPfk8, 2, m, &cDelay_1QiNPfk8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QCrimJlI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JokX5uOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WrDyEsyh, 0, m, &hTable_WrDyEsyh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s9aNCpAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_Oi0yljSQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iO8ZBx9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WrDyEsyh, 0, m, &hTable_WrDyEsyh_sendMessage);
}

void Heavy_ChaffVerb::cCast_QCrimJlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1QiNPfk8, 0, m, &cDelay_1QiNPfk8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RXPU2zkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_QF8BX84V, 2, m, &cDelay_QF8BX84V_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oZtW7ZmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eErH9xec, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_tVDEVsh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FDviMPdX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FDviMPdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IEudVhbc_sendMessage);
}

void Heavy_ChaffVerb::cDelay_SRCzwI6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SRCzwI6K, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M1kVQ2CK, 0, m, &cDelay_M1kVQ2CK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SRCzwI6K, 0, m, &cDelay_SRCzwI6K_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_J9IhJjcq, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_M1kVQ2CK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M1kVQ2CK, m);
  cMsg_wKAsQ9aF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_OV8ndZHQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_k6OvjmJU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_PtctDk7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pgYlMVMW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_zVxuWmbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CK5hb1Zb_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SRCzwI6K, 2, m, &cDelay_SRCzwI6K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UdVcAnpR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pgYlMVMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zVxuWmbl, 0, m, &hTable_zVxuWmbl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IEudVhbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_PtctDk7q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wKAsQ9aF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zVxuWmbl, 0, m, &hTable_zVxuWmbl_sendMessage);
}

void Heavy_ChaffVerb::cCast_UdVcAnpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SRCzwI6K, 0, m, &cDelay_SRCzwI6K_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CK5hb1Zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_M1kVQ2CK, 2, m, &cDelay_M1kVQ2CK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_k6OvjmJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_J9IhJjcq, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_Ba3XQTw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rDxzxtFK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rDxzxtFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cQ1c4gi3_sendMessage);
}

void Heavy_ChaffVerb::cDelay_za2DeifV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_za2DeifV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HyZbH4Cs, 0, m, &cDelay_HyZbH4Cs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_za2DeifV, 0, m, &cDelay_za2DeifV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_B4ISYUzw, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_HyZbH4Cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HyZbH4Cs, m);
  cMsg_n16ikjKk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_lmXgS3RA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vprmC72L_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_aN8B92Cl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yZKVPDyZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_glpRfysY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nUNN4ytE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_za2DeifV, 2, m, &cDelay_za2DeifV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WAGR6bPd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yZKVPDyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_glpRfysY, 0, m, &hTable_glpRfysY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cQ1c4gi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_aN8B92Cl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_n16ikjKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_glpRfysY, 0, m, &hTable_glpRfysY_sendMessage);
}

void Heavy_ChaffVerb::cCast_WAGR6bPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_za2DeifV, 0, m, &cDelay_za2DeifV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nUNN4ytE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_HyZbH4Cs, 2, m, &cDelay_HyZbH4Cs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vprmC72L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_B4ISYUzw, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_9HJWqs6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vhcDeJ0A_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vhcDeJ0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_exvLzd6Q_sendMessage);
}

void Heavy_ChaffVerb::cDelay_td6dYAEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_td6dYAEJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_S9sVtf8h, 0, m, &cDelay_S9sVtf8h_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_td6dYAEJ, 0, m, &cDelay_td6dYAEJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_RlipCkZz, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_S9sVtf8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S9sVtf8h, m);
  cMsg_iCViak7V_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_5u44pXIS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_xgpPxLSW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_59yj875g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vCkHrcI4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_4XUDdaNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PVy4cHWN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_td6dYAEJ, 2, m, &cDelay_td6dYAEJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p3XY6GpI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vCkHrcI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_4XUDdaNR, 0, m, &hTable_4XUDdaNR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_exvLzd6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_59yj875g_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iCViak7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_4XUDdaNR, 0, m, &hTable_4XUDdaNR_sendMessage);
}

void Heavy_ChaffVerb::cCast_p3XY6GpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_td6dYAEJ, 0, m, &cDelay_td6dYAEJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PVy4cHWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_S9sVtf8h, 2, m, &cDelay_S9sVtf8h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xgpPxLSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_RlipCkZz, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_sslaJDLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_rzfDCGjt, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_i3VtgeCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_xanK1odK, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_rtZtDge2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_e0T024Ts_sendMessage);
}

void Heavy_ChaffVerb::cBinop_e0T024Ts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_cktvigB2_sendMessage);
}

void Heavy_ChaffVerb::cVar_LQ7Uy73Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HsLUivEO, HV_BINOP_MULTIPLY, 0, m, &cBinop_HsLUivEO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ub5XrkaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jM2KkQyo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jM2KkQyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jRjaIfhp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_HsLUivEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CDCAZEC7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_W2CpwBRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HsLUivEO, HV_BINOP_MULTIPLY, 1, m, &cBinop_HsLUivEO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jRjaIfhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_W2CpwBRX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CDCAZEC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_i1a8rzz4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_i1a8rzz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_t78OsyQW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VypEsHX0, m);
}

void Heavy_ChaffVerb::cBinop_t78OsyQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OZkm92vB, m);
}

void Heavy_ChaffVerb::cVar_Sb3msu5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_iblLCVTP_sendMessage);
}

void Heavy_ChaffVerb::cVar_qPswlB5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rtZtDge2_sendMessage);
}

void Heavy_ChaffVerb::cVar_rrpl4jes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_4GHJ2yjG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_wFDJExrU, 0, m, &cIf_wFDJExrU_sendMessage);
}

void Heavy_ChaffVerb::cVar_dLKsQoj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6erlmA2C_sendMessage);
}

void Heavy_ChaffVerb::cIf_wFDJExrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_g21Oxk4T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_6FSzTCbJ, 0, m, &cVar_6FSzTCbJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_4GHJ2yjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wFDJExrU, 1, m, &cIf_wFDJExrU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6erlmA2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_R1fMT7M4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_R1fMT7M4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GVVDrayn, 0, m, &cVar_GVVDrayn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UikRYH61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OgkOJsD7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_OgkOJsD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0dJOA3GR_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zpPkhuzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zpPkhuzb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kJSspeuv, 0, m, &cDelay_kJSspeuv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zpPkhuzb, 0, m, &cDelay_zpPkhuzb_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ClZu3Zl9, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_kJSspeuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kJSspeuv, m);
  cMsg_umKo0w9d_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_VV5ZGEHQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_V0ge2EX3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_lQZSwdxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z5qZuLFQ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_00dwCZyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hn4cN6n5_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zpPkhuzb, 2, m, &cDelay_zpPkhuzb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Uut2vlhN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_z5qZuLFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_00dwCZyI, 0, m, &hTable_00dwCZyI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0dJOA3GR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_lQZSwdxf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_umKo0w9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_00dwCZyI, 0, m, &hTable_00dwCZyI_sendMessage);
}

void Heavy_ChaffVerb::cCast_Uut2vlhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zpPkhuzb, 0, m, &cDelay_zpPkhuzb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hn4cN6n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kJSspeuv, 2, m, &cDelay_kJSspeuv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_V0ge2EX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ClZu3Zl9, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_nu3yr8jY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kb3oMvoy, HV_BINOP_SUBTRACT, 0, m, &cBinop_Kb3oMvoy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KREWiVtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FK2XxHrX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FK2XxHrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_O1gFRLvE_sendMessage);
}

void Heavy_ChaffVerb::cVar_sGVA8tu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J1fX2LS6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_bGrs1Z2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bGrs1Z2t, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JkXcy9Fg, 0, m, &cDelay_JkXcy9Fg_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_k9qNzWUH, 0, m, &sTabread_k9qNzWUH_sendMessage);
}

void Heavy_ChaffVerb::cDelay_JkXcy9Fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JkXcy9Fg, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_k9qNzWUH, 0, m, &sTabread_k9qNzWUH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JkXcy9Fg, 0, m, &cDelay_JkXcy9Fg_sendMessage);
}

void Heavy_ChaffVerb::sTabread_k9qNzWUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ftTNl326, HV_BINOP_SUBTRACT, 0, m, &cBinop_ftTNl326_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_IxOAtp6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ygvDRX0h, HV_BINOP_MAX, 0, m, &cBinop_ygvDRX0h_sendMessage);
}

void Heavy_ChaffVerb::cBinop_O1gFRLvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IxOAtp6o, HV_BINOP_MULTIPLY, 0, m, &cBinop_IxOAtp6o_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Kb3oMvoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JRWL5Z9p_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_k9qNzWUH, 0, m, &sTabread_k9qNzWUH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r8osOAC7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fwR3BNln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ftTNl326, HV_BINOP_SUBTRACT, 1, m, &cBinop_ftTNl326_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JkXcy9Fg, 2, m, &cDelay_JkXcy9Fg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_J1fX2LS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fwR3BNln_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JRWL5Z9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bGrs1Z2t, 0, m, &cDelay_bGrs1Z2t_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JkXcy9Fg, 0, m, &cDelay_JkXcy9Fg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bhlVoelI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ygvDRX0h, HV_BINOP_MAX, 1, m, &cBinop_ygvDRX0h_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ygvDRX0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kb3oMvoy, HV_BINOP_SUBTRACT, 1, m, &cBinop_Kb3oMvoy_sendMessage);
}

void Heavy_ChaffVerb::cCast_r8osOAC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bGrs1Z2t, 0, m, &cDelay_bGrs1Z2t_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Tcurz7kM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bGrs1Z2t, 2, m, &cDelay_bGrs1Z2t_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ftTNl326_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Tcurz7kM_sendMessage);
}

void Heavy_ChaffVerb::cCast_tcvi2f12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sGVA8tu7, 0, m, &cVar_sGVA8tu7_sendMessage);
  cMsg_KREWiVtu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nu3yr8jY, 0, m, &cTabhead_nu3yr8jY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ucxX5WIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KMAEv8St_sendMessage);
}

void Heavy_ChaffVerb::cSystem_KMAEv8St_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HgcR4ASd_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ltkTCAOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ltkTCAOk, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zqNl1EdY, 0, m, &cDelay_zqNl1EdY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ltkTCAOk, 0, m, &cDelay_ltkTCAOk_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3hr2lOhj, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_zqNl1EdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zqNl1EdY, m);
  cMsg_YX0VRwtm_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_21r4qgHv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_XaVsA9cc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_NFeE4gli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IKeMu02t_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_kiB7ZZsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SFdaYri1_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ltkTCAOk, 2, m, &cDelay_ltkTCAOk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5UzYo420_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IKeMu02t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_kiB7ZZsy, 0, m, &hTable_kiB7ZZsy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HgcR4ASd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_NFeE4gli_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YX0VRwtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_kiB7ZZsy, 0, m, &hTable_kiB7ZZsy_sendMessage);
}

void Heavy_ChaffVerb::cCast_5UzYo420_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ltkTCAOk, 0, m, &cDelay_ltkTCAOk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SFdaYri1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_zqNl1EdY, 2, m, &cDelay_zqNl1EdY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XaVsA9cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3hr2lOhj, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_JwAzpeA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCKVMiXz, HV_BINOP_SUBTRACT, 0, m, &cBinop_DCKVMiXz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NqpNgXv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mA8lQi4M_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mA8lQi4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jS6OzgyI_sendMessage);
}

void Heavy_ChaffVerb::cVar_FVZAI5He_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cVjDhp67_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_BZfoh41d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BZfoh41d, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TmaTojev, 0, m, &cDelay_TmaTojev_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ND6Qevho, 0, m, &sTabread_ND6Qevho_sendMessage);
}

void Heavy_ChaffVerb::cDelay_TmaTojev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TmaTojev, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ND6Qevho, 0, m, &sTabread_ND6Qevho_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TmaTojev, 0, m, &cDelay_TmaTojev_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ND6Qevho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uaT91nnW, HV_BINOP_SUBTRACT, 0, m, &cBinop_uaT91nnW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_UhuNsDeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eaf84Jp4, HV_BINOP_MAX, 0, m, &cBinop_Eaf84Jp4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jS6OzgyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UhuNsDeA, HV_BINOP_MULTIPLY, 0, m, &cBinop_UhuNsDeA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DCKVMiXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GkcmvXMW_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ND6Qevho, 0, m, &sTabread_ND6Qevho_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q7blpZqu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_PQ0vbzdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uaT91nnW, HV_BINOP_SUBTRACT, 1, m, &cBinop_uaT91nnW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TmaTojev, 2, m, &cDelay_TmaTojev_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cVjDhp67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PQ0vbzdy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GkcmvXMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BZfoh41d, 0, m, &cDelay_BZfoh41d_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TmaTojev, 0, m, &cDelay_TmaTojev_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Y0OkFtEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eaf84Jp4, HV_BINOP_MAX, 1, m, &cBinop_Eaf84Jp4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Eaf84Jp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCKVMiXz, HV_BINOP_SUBTRACT, 1, m, &cBinop_DCKVMiXz_sendMessage);
}

void Heavy_ChaffVerb::cCast_Q7blpZqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BZfoh41d, 0, m, &cDelay_BZfoh41d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6yL9ythZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BZfoh41d, 2, m, &cDelay_BZfoh41d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uaT91nnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6yL9ythZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_M7GscuGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FVZAI5He, 0, m, &cVar_FVZAI5He_sendMessage);
  cMsg_NqpNgXv4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JwAzpeA3, 0, m, &cTabhead_JwAzpeA3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nQeGRkHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_drzuqhYS_sendMessage);
}

void Heavy_ChaffVerb::cSystem_drzuqhYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CUznyTDc_sendMessage);
}

void Heavy_ChaffVerb::cDelay_AYkluoWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AYkluoWd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EEoNKK6V, 0, m, &cDelay_EEoNKK6V_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AYkluoWd, 0, m, &cDelay_AYkluoWd_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_T6lcn9rJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_EEoNKK6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EEoNKK6V, m);
  cMsg_DaEQCjbh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_hdcXnqjc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qYELv9IV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_zBKuMnC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCKtnfcF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_dOOXAKYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jJtuBnYE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AYkluoWd, 2, m, &cDelay_AYkluoWd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4TQSl2Ov_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BCKtnfcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_dOOXAKYB, 0, m, &hTable_dOOXAKYB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CUznyTDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_zBKuMnC3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DaEQCjbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_dOOXAKYB, 0, m, &hTable_dOOXAKYB_sendMessage);
}

void Heavy_ChaffVerb::cCast_4TQSl2Ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AYkluoWd, 0, m, &cDelay_AYkluoWd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jJtuBnYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_EEoNKK6V, 2, m, &cDelay_EEoNKK6V_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qYELv9IV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_T6lcn9rJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_6JldcV9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EWesMM5f, HV_BINOP_SUBTRACT, 0, m, &cBinop_EWesMM5f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G2QOlwh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_45LEdCLo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_45LEdCLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yCYSkDjh_sendMessage);
}

void Heavy_ChaffVerb::cVar_NWvma2sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Noq0F4uA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_JcAaMisi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JcAaMisi, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6l96BVQF, 0, m, &cDelay_6l96BVQF_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lpoU3cAm, 0, m, &sTabread_lpoU3cAm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_6l96BVQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6l96BVQF, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lpoU3cAm, 0, m, &sTabread_lpoU3cAm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6l96BVQF, 0, m, &cDelay_6l96BVQF_sendMessage);
}

void Heavy_ChaffVerb::sTabread_lpoU3cAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GIoBNiCY, HV_BINOP_SUBTRACT, 0, m, &cBinop_GIoBNiCY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_kmEZgEYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z8rybyIm, HV_BINOP_MAX, 0, m, &cBinop_Z8rybyIm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yCYSkDjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kmEZgEYj, HV_BINOP_MULTIPLY, 0, m, &cBinop_kmEZgEYj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EWesMM5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Oog9KdV7_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lpoU3cAm, 0, m, &sTabread_lpoU3cAm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GbnIQoTG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8vtEKEbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GIoBNiCY, HV_BINOP_SUBTRACT, 1, m, &cBinop_GIoBNiCY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6l96BVQF, 2, m, &cDelay_6l96BVQF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Noq0F4uA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8vtEKEbd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Oog9KdV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcAaMisi, 0, m, &cDelay_JcAaMisi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6l96BVQF, 0, m, &cDelay_6l96BVQF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_htp5mY6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z8rybyIm, HV_BINOP_MAX, 1, m, &cBinop_Z8rybyIm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Z8rybyIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EWesMM5f, HV_BINOP_SUBTRACT, 1, m, &cBinop_EWesMM5f_sendMessage);
}

void Heavy_ChaffVerb::cCast_GbnIQoTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcAaMisi, 0, m, &cDelay_JcAaMisi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MZc5Tz2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcAaMisi, 2, m, &cDelay_JcAaMisi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GIoBNiCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MZc5Tz2w_sendMessage);
}

void Heavy_ChaffVerb::cCast_I2dkhvtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NWvma2sh, 0, m, &cVar_NWvma2sh_sendMessage);
  cMsg_G2QOlwh7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6JldcV9Y, 0, m, &cTabhead_6JldcV9Y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SFrczmDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ccMK73yF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ccMK73yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_anIA1nsT_sendMessage);
}

void Heavy_ChaffVerb::cDelay_THHfAEYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_THHfAEYq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wCBgeqzh, 0, m, &cDelay_wCBgeqzh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_THHfAEYq, 0, m, &cDelay_THHfAEYq_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ETw3W8dB, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_wCBgeqzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wCBgeqzh, m);
  cMsg_6hcgXoFb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_GaEq6lXV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_QTsPnp7K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_SLVDLBXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CIqjDmpl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_u8Ki07XJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IQeuAzcR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_THHfAEYq, 2, m, &cDelay_THHfAEYq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F61g8nbl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CIqjDmpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_u8Ki07XJ, 0, m, &hTable_u8Ki07XJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_anIA1nsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_SLVDLBXC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6hcgXoFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_u8Ki07XJ, 0, m, &hTable_u8Ki07XJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_F61g8nbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_THHfAEYq, 0, m, &cDelay_THHfAEYq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IQeuAzcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wCBgeqzh, 2, m, &cDelay_wCBgeqzh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QTsPnp7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ETw3W8dB, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_PTyCCfqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_78c2qq9a, HV_BINOP_SUBTRACT, 0, m, &cBinop_78c2qq9a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_znrmieaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ku5ZSO3x_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Ku5ZSO3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RGvQbsMF_sendMessage);
}

void Heavy_ChaffVerb::cVar_ONIUnS9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZsMW14bb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_KJgRwDOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KJgRwDOK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iSYhq1ua, 0, m, &cDelay_iSYhq1ua_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ty0k8Ros, 0, m, &sTabread_ty0k8Ros_sendMessage);
}

void Heavy_ChaffVerb::cDelay_iSYhq1ua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iSYhq1ua, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ty0k8Ros, 0, m, &sTabread_ty0k8Ros_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iSYhq1ua, 0, m, &cDelay_iSYhq1ua_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ty0k8Ros_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_nfGNihvX, HV_BINOP_SUBTRACT, 0, m, &cBinop_nfGNihvX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_chZVff0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dS5DDe2Y, HV_BINOP_MAX, 0, m, &cBinop_dS5DDe2Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RGvQbsMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_chZVff0S, HV_BINOP_MULTIPLY, 0, m, &cBinop_chZVff0S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_78c2qq9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JREnk2XQ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ty0k8Ros, 0, m, &sTabread_ty0k8Ros_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MOIPCeOC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_r6znkUwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nfGNihvX, HV_BINOP_SUBTRACT, 1, m, &cBinop_nfGNihvX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iSYhq1ua, 2, m, &cDelay_iSYhq1ua_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZsMW14bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r6znkUwa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JREnk2XQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KJgRwDOK, 0, m, &cDelay_KJgRwDOK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iSYhq1ua, 0, m, &cDelay_iSYhq1ua_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hZYJrYhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_dS5DDe2Y, HV_BINOP_MAX, 1, m, &cBinop_dS5DDe2Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dS5DDe2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_78c2qq9a, HV_BINOP_SUBTRACT, 1, m, &cBinop_78c2qq9a_sendMessage);
}

void Heavy_ChaffVerb::cCast_MOIPCeOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KJgRwDOK, 0, m, &cDelay_KJgRwDOK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KaZRFf8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KJgRwDOK, 2, m, &cDelay_KJgRwDOK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nfGNihvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KaZRFf8F_sendMessage);
}

void Heavy_ChaffVerb::cCast_4lmcWx8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ONIUnS9l, 0, m, &cVar_ONIUnS9l_sendMessage);
  cMsg_znrmieaH_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PTyCCfqe, 0, m, &cTabhead_PTyCCfqe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FSbIqJi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h4nyjOqI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_h4nyjOqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bkIdbIOQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_DpDEMOYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DpDEMOYZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_30ImelmY, 0, m, &cDelay_30ImelmY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DpDEMOYZ, 0, m, &cDelay_DpDEMOYZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lc4Ag43H, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_30ImelmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_30ImelmY, m);
  cMsg_JBebeSXl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_GeWK1pQ0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_PngwMt2j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_91Fe4Z7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_in4NXhUj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_rOY9kfy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dmxbfmhZ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DpDEMOYZ, 2, m, &cDelay_DpDEMOYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xqdhfs7s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_in4NXhUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_rOY9kfy5, 0, m, &hTable_rOY9kfy5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bkIdbIOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_91Fe4Z7x_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JBebeSXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_rOY9kfy5, 0, m, &hTable_rOY9kfy5_sendMessage);
}

void Heavy_ChaffVerb::cCast_xqdhfs7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DpDEMOYZ, 0, m, &cDelay_DpDEMOYZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dmxbfmhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_30ImelmY, 2, m, &cDelay_30ImelmY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PngwMt2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lc4Ag43H, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_gMHI4n5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SsBf06Qr, HV_BINOP_SUBTRACT, 0, m, &cBinop_SsBf06Qr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_McuBaCDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NzC8OmfR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_NzC8OmfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_itL7IqNl_sendMessage);
}

void Heavy_ChaffVerb::cVar_30oCpuNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QHfC9qwP_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_UevsEoYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UevsEoYG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HOW6z604, 0, m, &cDelay_HOW6z604_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Uhcv57ms, 0, m, &sTabread_Uhcv57ms_sendMessage);
}

void Heavy_ChaffVerb::cDelay_HOW6z604_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HOW6z604, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Uhcv57ms, 0, m, &sTabread_Uhcv57ms_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HOW6z604, 0, m, &cDelay_HOW6z604_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Uhcv57ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hE3NUL99, HV_BINOP_SUBTRACT, 0, m, &cBinop_hE3NUL99_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_wBw3bCBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckd75gKN, HV_BINOP_MAX, 0, m, &cBinop_ckd75gKN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_itL7IqNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wBw3bCBP, HV_BINOP_MULTIPLY, 0, m, &cBinop_wBw3bCBP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SsBf06Qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iSdO94zE_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Uhcv57ms, 0, m, &sTabread_Uhcv57ms_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X70RzQP4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VwRlTAFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hE3NUL99, HV_BINOP_SUBTRACT, 1, m, &cBinop_hE3NUL99_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HOW6z604, 2, m, &cDelay_HOW6z604_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QHfC9qwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VwRlTAFt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iSdO94zE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UevsEoYG, 0, m, &cDelay_UevsEoYG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HOW6z604, 0, m, &cDelay_HOW6z604_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ej9Gjrz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckd75gKN, HV_BINOP_MAX, 1, m, &cBinop_ckd75gKN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ckd75gKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SsBf06Qr, HV_BINOP_SUBTRACT, 1, m, &cBinop_SsBf06Qr_sendMessage);
}

void Heavy_ChaffVerb::cCast_X70RzQP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UevsEoYG, 0, m, &cDelay_UevsEoYG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KxAZcFJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UevsEoYG, 2, m, &cDelay_UevsEoYG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hE3NUL99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KxAZcFJL_sendMessage);
}

void Heavy_ChaffVerb::cCast_mYxeEien_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_30oCpuNa, 0, m, &cVar_30oCpuNa_sendMessage);
  cMsg_McuBaCDL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_gMHI4n5h, 0, m, &cTabhead_gMHI4n5h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dqDmw13r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RQNu20sy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RQNu20sy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OcLmNWnw_sendMessage);
}

void Heavy_ChaffVerb::cDelay_dUnxNnXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dUnxNnXr, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tzM4CHIq, 0, m, &cDelay_tzM4CHIq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dUnxNnXr, 0, m, &cDelay_dUnxNnXr_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_r7FOShdG, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_tzM4CHIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tzM4CHIq, m);
  cMsg_SEQjVsXC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_IeI5ojiA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_zkHLurIl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_XtIWXmTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4aCsqjLi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_TPX2aUYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wggcPKwl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dUnxNnXr, 2, m, &cDelay_dUnxNnXr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hc3rRVoV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4aCsqjLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TPX2aUYJ, 0, m, &hTable_TPX2aUYJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OcLmNWnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_XtIWXmTL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SEQjVsXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TPX2aUYJ, 0, m, &hTable_TPX2aUYJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_hc3rRVoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dUnxNnXr, 0, m, &cDelay_dUnxNnXr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wggcPKwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_tzM4CHIq, 2, m, &cDelay_tzM4CHIq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zkHLurIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_r7FOShdG, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_vkp0pxjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jbQQRUar, HV_BINOP_SUBTRACT, 0, m, &cBinop_jbQQRUar_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ULpLAbd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_j76Qildp_sendMessage);
}

void Heavy_ChaffVerb::cSystem_j76Qildp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IiZbv6IH_sendMessage);
}

void Heavy_ChaffVerb::cVar_ENbtR69T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Ne0bS2u_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_1IhddQu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1IhddQu4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jARMdbvI, 0, m, &cDelay_jARMdbvI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xkzta5HU, 0, m, &sTabread_xkzta5HU_sendMessage);
}

void Heavy_ChaffVerb::cDelay_jARMdbvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jARMdbvI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xkzta5HU, 0, m, &sTabread_xkzta5HU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jARMdbvI, 0, m, &cDelay_jARMdbvI_sendMessage);
}

void Heavy_ChaffVerb::sTabread_xkzta5HU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_fkDIqTHg, HV_BINOP_SUBTRACT, 0, m, &cBinop_fkDIqTHg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_kqNABIh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zgyjSQdr, HV_BINOP_MAX, 0, m, &cBinop_zgyjSQdr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IiZbv6IH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kqNABIh0, HV_BINOP_MULTIPLY, 0, m, &cBinop_kqNABIh0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jbQQRUar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xzJJOzn2_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xkzta5HU, 0, m, &sTabread_xkzta5HU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SQ9a00RQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Ll3VOl0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkDIqTHg, HV_BINOP_SUBTRACT, 1, m, &cBinop_fkDIqTHg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jARMdbvI, 2, m, &cDelay_jARMdbvI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0Ne0bS2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ll3VOl0b_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xzJJOzn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1IhddQu4, 0, m, &cDelay_1IhddQu4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jARMdbvI, 0, m, &cDelay_jARMdbvI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RyMzMOq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_zgyjSQdr, HV_BINOP_MAX, 1, m, &cBinop_zgyjSQdr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zgyjSQdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jbQQRUar, HV_BINOP_SUBTRACT, 1, m, &cBinop_jbQQRUar_sendMessage);
}

void Heavy_ChaffVerb::cCast_SQ9a00RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1IhddQu4, 0, m, &cDelay_1IhddQu4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iNWI7fXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1IhddQu4, 2, m, &cDelay_1IhddQu4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fkDIqTHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iNWI7fXK_sendMessage);
}

void Heavy_ChaffVerb::cCast_ATcLMJFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ENbtR69T, 0, m, &cVar_ENbtR69T_sendMessage);
  cMsg_ULpLAbd0_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vkp0pxjB, 0, m, &cTabhead_vkp0pxjB_sendMessage);
}

void Heavy_ChaffVerb::cVar_6FSzTCbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LQ7Uy73Y, 0, m, &cVar_LQ7Uy73Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JdLFrBBv, 0, m, &cVar_JdLFrBBv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m2VCZqqs, 0, m, &cVar_m2VCZqqs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MVK3sVDp, 0, m, &cVar_MVK3sVDp_sendMessage);
}

void Heavy_ChaffVerb::cVar_GVVDrayn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_Q4IxNzNq_sendMessage);
}

void Heavy_ChaffVerb::cPack_ZRFxjNoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_dAYgHCK0, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_JdLFrBBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yLa8SbA6, HV_BINOP_MULTIPLY, 0, m, &cBinop_yLa8SbA6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TnBJxHmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_d9TdFY6y_sendMessage);
}

void Heavy_ChaffVerb::cSystem_d9TdFY6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jbBP1282_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_yLa8SbA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AmJGBbjZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3zyR2Nnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yLa8SbA6, HV_BINOP_MULTIPLY, 1, m, &cBinop_yLa8SbA6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jbBP1282_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3zyR2Nnr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AmJGBbjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_el1WTBix_sendMessage);
}

void Heavy_ChaffVerb::cBinop_el1WTBix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mYWfDJ7D_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CacsI8l9, m);
}

void Heavy_ChaffVerb::cBinop_mYWfDJ7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Py3j6gt0, m);
}

void Heavy_ChaffVerb::cVar_m2VCZqqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IvPJbE6N, HV_BINOP_MULTIPLY, 0, m, &cBinop_IvPJbE6N_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xJABeDwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z0UwMsOG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Z0UwMsOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aPpXNmrn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_IvPJbE6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uXngXIHs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Kzk8ugNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IvPJbE6N, HV_BINOP_MULTIPLY, 1, m, &cBinop_IvPJbE6N_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aPpXNmrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Kzk8ugNF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uXngXIHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cf3IASoS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cf3IASoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IqvgcvKt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6hY6qzRm, m);
}

void Heavy_ChaffVerb::cBinop_IqvgcvKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mBoQjvqh, m);
}

void Heavy_ChaffVerb::cVar_MVK3sVDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kPCJeiAP, HV_BINOP_MULTIPLY, 0, m, &cBinop_kPCJeiAP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0w7CcesD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZPJQS6qW_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZPJQS6qW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sSMhgtJj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_kPCJeiAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CAIRRRqC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qlwai7tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kPCJeiAP, HV_BINOP_MULTIPLY, 1, m, &cBinop_kPCJeiAP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sSMhgtJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qlwai7tm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CAIRRRqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0T8n6JdQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0T8n6JdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7FsFGWTQ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_o9jWtfAP, m);
}

void Heavy_ChaffVerb::cBinop_7FsFGWTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MUNheMJU, m);
}

void Heavy_ChaffVerb::cBinop_cktvigB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_i3VtgeCa, 0, m, &cPack_i3VtgeCa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_g21Oxk4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_6FSzTCbJ, 0, m, &cVar_6FSzTCbJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Q4IxNzNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ZRFxjNoq, 0, m, &cPack_ZRFxjNoq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iblLCVTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_sslaJDLL, 0, m, &cPack_sslaJDLL_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_GJzEKMRA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_ouzELE3b_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_ouzELE3b_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1esBkXxG_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_cFYsL34s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cFYsL34s, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cFYsL34s, 0, m, &cDelay_cFYsL34s_sendMessage);
  cSwitchcase_W4T1IVgY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_1esBkXxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ouzELE3b_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cFYsL34s, 0, m, &cDelay_cFYsL34s_sendMessage);
  cSwitchcase_W4T1IVgY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_fyN4GHmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_G0czi4sh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_G0czi4sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EGrGjqjC_sendMessage);
}

void Heavy_ChaffVerb::cVar_SmUxTTYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7PgJGQ1v, HV_BINOP_MULTIPLY, 0, m, &cBinop_7PgJGQ1v_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ouzELE3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cFYsL34s, 0, m, &cDelay_cFYsL34s_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j4rEFGsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cFYsL34s, 2, m, &cDelay_cFYsL34s_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EGrGjqjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7PgJGQ1v, HV_BINOP_MULTIPLY, 1, m, &cBinop_7PgJGQ1v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7PgJGQ1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_j4rEFGsB_sendMessage);
}

void Heavy_ChaffVerb::cVar_jN7qYR6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_L3k96Y1n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_iuW79QQq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_qbtuQ1Dz_sendMessage);
}

void Heavy_ChaffVerb::cVar_mL7d4R82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_J0WGoSv6_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_3vkpVd19, 0, m, &cIf_3vkpVd19_sendMessage);
}

void Heavy_ChaffVerb::cUnop_DOnSP4cH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3RCwtewE, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_3RCwtewE_sendMessage);
}

void Heavy_ChaffVerb::cUnop_ZoRyefwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3RCwtewE, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_3RCwtewE_sendMessage);
}

void Heavy_ChaffVerb::cIf_3vkpVd19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_ZoRyefwX_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_DOnSP4cH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_J0WGoSv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3vkpVd19, 1, m, &cIf_3vkpVd19_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fAr2GKRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_saDaTplh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_saDaTplh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qgSuf1Eh_sendMessage);
}

void Heavy_ChaffVerb::cDelay_y0VvwmZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y0VvwmZa, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LHnv6lY2, 0, m, &cDelay_LHnv6lY2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y0VvwmZa, 0, m, &cDelay_y0VvwmZa_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Gi2itpse, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_LHnv6lY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LHnv6lY2, m);
  cMsg_VJErq6WH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Yf5aqF2T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_rLEh0Vmr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_eKsJDMgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6aEu6NQG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_pL6tXkvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oZPWBmum_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y0VvwmZa, 2, m, &cDelay_y0VvwmZa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CYzBfWI2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6aEu6NQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_pL6tXkvh, 0, m, &hTable_pL6tXkvh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qgSuf1Eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_eKsJDMgp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VJErq6WH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_pL6tXkvh, 0, m, &hTable_pL6tXkvh_sendMessage);
}

void Heavy_ChaffVerb::cCast_CYzBfWI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y0VvwmZa, 0, m, &cDelay_y0VvwmZa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oZPWBmum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_LHnv6lY2, 2, m, &cDelay_LHnv6lY2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rLEh0Vmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Gi2itpse, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_QcoDdV1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B2dz2tW0, HV_BINOP_SUBTRACT, 0, m, &cBinop_B2dz2tW0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aYfvCA0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5gU1dy3p_sendMessage);
}

void Heavy_ChaffVerb::cSystem_5gU1dy3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_s8rhR9mf_sendMessage);
}

void Heavy_ChaffVerb::cVar_mDpUoG2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vnuuUYS3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_0Bhw2Y1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0Bhw2Y1Y, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RJp18UEI, 0, m, &cDelay_RJp18UEI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8CL64JUv, 0, m, &sTabread_8CL64JUv_sendMessage);
}

void Heavy_ChaffVerb::cDelay_RJp18UEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RJp18UEI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8CL64JUv, 0, m, &sTabread_8CL64JUv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RJp18UEI, 0, m, &cDelay_RJp18UEI_sendMessage);
}

void Heavy_ChaffVerb::sTabread_8CL64JUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ioKPWgCh, HV_BINOP_SUBTRACT, 0, m, &cBinop_ioKPWgCh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_XydBZroK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KPLa4LXN, HV_BINOP_MAX, 0, m, &cBinop_KPLa4LXN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s8rhR9mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XydBZroK, HV_BINOP_MULTIPLY, 0, m, &cBinop_XydBZroK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_B2dz2tW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vPpZ9TbM_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8CL64JUv, 0, m, &sTabread_8CL64JUv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rZf5FHGc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vaTVIGKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ioKPWgCh, HV_BINOP_SUBTRACT, 1, m, &cBinop_ioKPWgCh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RJp18UEI, 2, m, &cDelay_RJp18UEI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vnuuUYS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vaTVIGKM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vPpZ9TbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Bhw2Y1Y, 0, m, &cDelay_0Bhw2Y1Y_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RJp18UEI, 0, m, &cDelay_RJp18UEI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BaZfrACR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_KPLa4LXN, HV_BINOP_MAX, 1, m, &cBinop_KPLa4LXN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KPLa4LXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B2dz2tW0, HV_BINOP_SUBTRACT, 1, m, &cBinop_B2dz2tW0_sendMessage);
}

void Heavy_ChaffVerb::cCast_rZf5FHGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Bhw2Y1Y, 0, m, &cDelay_0Bhw2Y1Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Qyd9y177_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Bhw2Y1Y, 2, m, &cDelay_0Bhw2Y1Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ioKPWgCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Qyd9y177_sendMessage);
}

void Heavy_ChaffVerb::cCast_BLn0fns5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mDpUoG2T, 0, m, &cVar_mDpUoG2T_sendMessage);
  cMsg_aYfvCA0a_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_QcoDdV1h, 0, m, &cTabhead_QcoDdV1h_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_PEg4CixI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S8OyKJU3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_S8OyKJU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fNd2xibE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_kPquj3oT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xyxw7h7R, HV_BINOP_ADD, 0, m, &cBinop_xyxw7h7R_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_rN8skTrS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YuqUQDXd_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_YuqUQDXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qzk6nmxp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_OBTS3FgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XVCGnkBk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LrxX92lR_sendMessage);
}

void Heavy_ChaffVerb::cVar_4PDJSD6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CC7o3Nrx, 0, m, &cVar_CC7o3Nrx_sendMessage);
}

void Heavy_ChaffVerb::cVar_CC7o3Nrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gjtnYbeE, HV_BINOP_ADD, 0, m, &cBinop_gjtnYbeE_sendMessage);
}

void Heavy_ChaffVerb::cVar_jVyfnYoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A8zgVzRX, HV_BINOP_ADD, 0, m, &cBinop_A8zgVzRX_sendMessage);
}

void Heavy_ChaffVerb::cVar_ydJzJNsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zl5iAOnC_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_xPHgj3KT, 0, m, &cIf_xPHgj3KT_sendMessage);
}

void Heavy_ChaffVerb::cUnop_rH3Sx7kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A8zgVzRX, HV_BINOP_ADD, 1, m, &cBinop_A8zgVzRX_sendMessage);
}

void Heavy_ChaffVerb::cUnop_O9sMtwBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A8zgVzRX, HV_BINOP_ADD, 1, m, &cBinop_A8zgVzRX_sendMessage);
}

void Heavy_ChaffVerb::cIf_xPHgj3KT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_O9sMtwBa_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_rH3Sx7kw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_zl5iAOnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xPHgj3KT, 1, m, &cIf_xPHgj3KT_sendMessage);
}

void Heavy_ChaffVerb::cVar_7xTWCzNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5S9bRQj0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kLcuxDza, 0, m, &cIf_kLcuxDza_sendMessage);
}

void Heavy_ChaffVerb::cUnop_GkBtZw2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pu8lqPWe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_LPueh9Ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pu8lqPWe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_kLcuxDza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_LPueh9Ul_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_GkBtZw2g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_5S9bRQj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kLcuxDza, 1, m, &cIf_kLcuxDza_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_pu8lqPWe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IVEnlmFj, 0, m, &cSlice_IVEnlmFj_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OUrAoUFp, 0, m, &cSlice_OUrAoUFp_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Web9D8mS_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_toPaKYVy_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_IVEnlmFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_q21putqw, 0, m, &cVar_q21putqw_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_q21putqw, 0, m, &cVar_q21putqw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_OUrAoUFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_N4pFfGdH, HV_BINOP_NEQ, 1, m, &cBinop_N4pFfGdH_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_q21putqw, 1, m, &cVar_q21putqw_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_N4pFfGdH, HV_BINOP_NEQ, 1, m, &cBinop_N4pFfGdH_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_q21putqw, 1, m, &cVar_q21putqw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_q21putqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kdNvEWBq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2qfkIPed_sendMessage);
}

void Heavy_ChaffVerb::cIf_lKgjFa6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_syNqpuMc_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nS5skm1N_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_syNqpuMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N4pFfGdH, HV_BINOP_NEQ, 1, m, &cBinop_N4pFfGdH_sendMessage);
}

void Heavy_ChaffVerb::cCast_nS5skm1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q21putqw, 0, m, &cVar_q21putqw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_N4pFfGdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lKgjFa6Q, 1, m, &cIf_lKgjFa6Q_sendMessage);
}

void Heavy_ChaffVerb::cCast_toPaKYVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lKgjFa6Q, 0, m, &cIf_lKgjFa6Q_sendMessage);
}

void Heavy_ChaffVerb::cCast_Web9D8mS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N4pFfGdH, HV_BINOP_NEQ, 0, m, &cBinop_N4pFfGdH_sendMessage);
}

void Heavy_ChaffVerb::cIf_0JuNAvFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_4PDJSD6t, 0, m, &cVar_4PDJSD6t_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_LYdjdLWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_0JuNAvFq, 0, m, &cIf_0JuNAvFq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_O9lkr9Ts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_0JuNAvFq, 0, m, &cIf_0JuNAvFq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_nf8Sp4Ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_0JuNAvFq, 0, m, &cIf_0JuNAvFq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_k08280IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_OBTS3FgY, 0, m, &cVar_OBTS3FgY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_9gY9NSUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jVyfnYoZ, 0, m, &cVar_jVyfnYoZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mjxu2Yqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LYdjdLWW, 1, m, &cIf_LYdjdLWW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8o7BFj5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nf8Sp4Ar, 1, m, &cIf_nf8Sp4Ar_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rwyqBu9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LYdjdLWW, 1, m, &cIf_LYdjdLWW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_O9lkr9Ts, 1, m, &cIf_O9lkr9Ts_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_nf8Sp4Ar, 1, m, &cIf_nf8Sp4Ar_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ir11yASN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kPquj3oT, 0, m, &cVar_kPquj3oT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JTztm6B4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Ir11yASN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qzk6nmxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_OBTS3FgY, 0, m, &cVar_OBTS3FgY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3RCwtewE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lMCeR05l, HV_BINOP_MULTIPLY, 0, m, &cBinop_lMCeR05l_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qbtuQ1Dz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3RCwtewE, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_3RCwtewE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UQ9P5d6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_O9lkr9Ts, 1, m, &cIf_O9lkr9Ts_sendMessage);
}

void Heavy_ChaffVerb::cBinop_A8zgVzRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_evaVesYe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3gzOIl9E_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PLOTSogW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0yBYa0wm, 0, m, &cVar_0yBYa0wm_sendMessage);
}

void Heavy_ChaffVerb::cCast_evaVesYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PLOTSogW, HV_BINOP_ADD, 1, m, &cBinop_PLOTSogW_sendMessage);
}

void Heavy_ChaffVerb::cCast_3gzOIl9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4PDJSD6t, 0, m, &cVar_4PDJSD6t_sendMessage);
}

void Heavy_ChaffVerb::cCast_2qfkIPed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jZhI0fvY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_kdNvEWBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rwyqBu9u_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_WJNHyY4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qPswlB5N, 0, m, &cVar_qPswlB5N_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lMCeR05l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O9lkr9Ts, 0, m, &cIf_O9lkr9Ts_sendMessage);
}

void Heavy_ChaffVerb::cBinop_diBUbZde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nf8Sp4Ar, 0, m, &cIf_nf8Sp4Ar_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oYWCPpCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NOZXvnJl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_diBUbZde_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L3k96Y1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_5T8aoSIY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5T8aoSIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_oYWCPpCy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iuW79QQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jN7qYR6X, 1, m, &cVar_jN7qYR6X_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hs1W8hnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iZViNGBn, 0, m, &cVar_iZViNGBn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wtSoDNbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SmUxTTYk, 0, m, &cVar_SmUxTTYk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fNd2xibE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_4PDJSD6t, 0, m, &cVar_4PDJSD6t_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xyxw7h7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YItALXs2, HV_BINOP_MULTIPLY, 0, m, &cBinop_YItALXs2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YItALXs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k08280IG, 0, m, &cIf_k08280IG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Fzbz7QoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PLOTSogW, HV_BINOP_ADD, 0, m, &cBinop_PLOTSogW_sendMessage);
}

void Heavy_ChaffVerb::cCast_XVCGnkBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fzbz7QoV, HV_BINOP_ADD, 1, m, &cBinop_Fzbz7QoV_sendMessage);
}

void Heavy_ChaffVerb::cCast_LrxX92lR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4PDJSD6t, 0, m, &cVar_4PDJSD6t_sendMessage);
}

void Heavy_ChaffVerb::cCast_AkwMCd7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0JuNAvFq, 1, m, &cIf_0JuNAvFq_sendMessage);
}

void Heavy_ChaffVerb::cCast_BlYHhPHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PEg4CixI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_7OiSWEtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kPquj3oT, 0, m, &cVar_kPquj3oT_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZjzpdXjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YItALXs2, HV_BINOP_MULTIPLY, 1, m, &cBinop_YItALXs2_sendMessage);
}

void Heavy_ChaffVerb::cCast_lYNJjWHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rN8skTrS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_Ibdxxev7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k08280IG, 1, m, &cIf_k08280IG_sendMessage);
}

void Heavy_ChaffVerb::cCast_wgl9bkov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xyxw7h7R, HV_BINOP_ADD, 1, m, &cBinop_xyxw7h7R_sendMessage);
}

void Heavy_ChaffVerb::cCast_gGZMaVEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kPquj3oT, 0, m, &cVar_kPquj3oT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Gx5Jbbj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fzbz7QoV, HV_BINOP_ADD, 0, m, &cBinop_Fzbz7QoV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gjtnYbeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gx5Jbbj6, HV_BINOP_MULTIPLY, 0, m, &cBinop_Gx5Jbbj6_sendMessage);
}

void Heavy_ChaffVerb::cCast_DQOAOi0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4PDJSD6t, 0, m, &cVar_4PDJSD6t_sendMessage);
}

void Heavy_ChaffVerb::cCast_0OQjflgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gx5Jbbj6, HV_BINOP_MULTIPLY, 1, m, &cBinop_Gx5Jbbj6_sendMessage);
}

void Heavy_ChaffVerb::cCast_JmhouV5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4PDJSD6t, 0, m, &cVar_4PDJSD6t_sendMessage);
}

void Heavy_ChaffVerb::cCast_z3oi8S2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gjtnYbeE, HV_BINOP_ADD, 1, m, &cBinop_gjtnYbeE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mJcgQSOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kdNvEWBq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2qfkIPed_sendMessage);
}

void Heavy_ChaffVerb::cReceive_aUab1fDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UikRYH61_sendMessage(_c, 0, m);
  cMsg_ucxX5WIT_sendMessage(_c, 0, m);
  cMsg_nQeGRkHM_sendMessage(_c, 0, m);
  cMsg_SFrczmDE_sendMessage(_c, 0, m);
  cMsg_FSbIqJi3_sendMessage(_c, 0, m);
  cMsg_dqDmw13r_sendMessage(_c, 0, m);
  cMsg_QavO5ehE_sendMessage(_c, 0, m);
  cMsg_BCDiCQz6_sendMessage(_c, 0, m);
  cMsg_tVDEVsh8_sendMessage(_c, 0, m);
  cMsg_Ba3XQTw4_sendMessage(_c, 0, m);
  cMsg_9HJWqs6M_sendMessage(_c, 0, m);
  cMsg_ub5XrkaS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LQ7Uy73Y, 0, m, &cVar_LQ7Uy73Y_sendMessage);
  cMsg_TnBJxHmc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JdLFrBBv, 0, m, &cVar_JdLFrBBv_sendMessage);
  cMsg_xJABeDwS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_m2VCZqqs, 0, m, &cVar_m2VCZqqs_sendMessage);
  cMsg_0w7CcesD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MVK3sVDp, 0, m, &cVar_MVK3sVDp_sendMessage);
  cMsg_0F9EVmSg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nSbWqOgd, 0, m, &cVar_nSbWqOgd_sendMessage);
  cMsg_62V7fRcm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iZViNGBn, 0, m, &cVar_iZViNGBn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Sb3msu5S, 0, m, &cVar_Sb3msu5S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qPswlB5N, 0, m, &cVar_qPswlB5N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rrpl4jes, 0, m, &cVar_rrpl4jes_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dLKsQoj0, 0, m, &cVar_dLKsQoj0_sendMessage);
  cMsg_fyN4GHmM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SmUxTTYk, 0, m, &cVar_SmUxTTYk_sendMessage);
  cMsg_fAr2GKRo_sendMessage(_c, 0, m);
  cSwitchcase_UOPM5CAn_onMessage(_c, NULL, 0, m, NULL);
  cMsg_fNd2xibE_sendMessage(_c, 0, m);
  cMsg_mJcgQSOG_sendMessage(_c, 0, m);
  cMsg_qzk6nmxp_sendMessage(_c, 0, m);
  cSwitchcase_GJzEKMRA_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_lO0N0vfP, 0, m, &cVar_lO0N0vfP_sendMessage);
  cMsg_mKa4R9Ra_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3jFLkH1g, 0, m, &cVar_3jFLkH1g_sendMessage);
  cMsg_m8A4XvIv_sendMessage(_c, 0, m);
  cMsg_XIaSgd3R_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Ln8eloxK, 0, m, &cVar_Ln8eloxK_sendMessage);
  cMsg_qj7AC8tQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MGwj9Nid, 0, m, &cTabhead_MGwj9Nid_sendMessage);
  cMsg_cH7ShmiZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_f4QIigP8, 0, m, &cVar_f4QIigP8_sendMessage);
  cMsg_VbLG2YRU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ht8yPDP4, 0, m, &cTabhead_ht8yPDP4_sendMessage);
  cMsg_tiCfMp5T_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IdzeTBDq, 0, m, &cVar_IdzeTBDq_sendMessage);
  cMsg_6zNeq73S_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_9LPq23HG, 0, m, &cTabhead_9LPq23HG_sendMessage);
  cMsg_FC2HBuZd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3veFdNr4, 0, m, &cVar_3veFdNr4_sendMessage);
  cMsg_g5sgzVUF_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_A0aSLEpF, 0, m, &cTabhead_A0aSLEpF_sendMessage);
  cMsg_bhlVoelI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sGVA8tu7, 0, m, &cVar_sGVA8tu7_sendMessage);
  cMsg_KREWiVtu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nu3yr8jY, 0, m, &cTabhead_nu3yr8jY_sendMessage);
  cMsg_Y0OkFtEo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FVZAI5He, 0, m, &cVar_FVZAI5He_sendMessage);
  cMsg_NqpNgXv4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JwAzpeA3, 0, m, &cTabhead_JwAzpeA3_sendMessage);
  cMsg_htp5mY6S_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NWvma2sh, 0, m, &cVar_NWvma2sh_sendMessage);
  cMsg_G2QOlwh7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6JldcV9Y, 0, m, &cTabhead_6JldcV9Y_sendMessage);
  cMsg_hZYJrYhr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ONIUnS9l, 0, m, &cVar_ONIUnS9l_sendMessage);
  cMsg_znrmieaH_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PTyCCfqe, 0, m, &cTabhead_PTyCCfqe_sendMessage);
  cMsg_Ej9Gjrz2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_30oCpuNa, 0, m, &cVar_30oCpuNa_sendMessage);
  cMsg_McuBaCDL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_gMHI4n5h, 0, m, &cTabhead_gMHI4n5h_sendMessage);
  cMsg_RyMzMOq0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ENbtR69T, 0, m, &cVar_ENbtR69T_sendMessage);
  cMsg_ULpLAbd0_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vkp0pxjB, 0, m, &cTabhead_vkp0pxjB_sendMessage);
  cMsg_BaZfrACR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mDpUoG2T, 0, m, &cVar_mDpUoG2T_sendMessage);
  cMsg_aYfvCA0a_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_QcoDdV1h, 0, m, &cTabhead_QcoDdV1h_sendMessage);
}

void Heavy_ChaffVerb::cReceive_pzpSrTyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_hs1W8hnR_sendMessage);
}

void Heavy_ChaffVerb::cReceive_X6Dwjhd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7xTWCzNT, 0, m, &cVar_7xTWCzNT_sendMessage);
}

void Heavy_ChaffVerb::cReceive_7WLPvbdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mL7d4R82, 0, m, &cVar_mL7d4R82_sendMessage);
}

void Heavy_ChaffVerb::cReceive_kwa9qNLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lMCeR05l, HV_BINOP_MULTIPLY, 1, m, &cBinop_lMCeR05l_sendMessage);
}

void Heavy_ChaffVerb::cReceive_YrYP88Yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z3oi8S2z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JmhouV5D_sendMessage);
}

void Heavy_ChaffVerb::cReceive_BGvFqjmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0OQjflgE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DQOAOi0P_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Gh1y0I3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jVyfnYoZ, 0, m, &cVar_jVyfnYoZ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_caG62iMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9gY9NSUC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ydJzJNsf, 0, m, &cVar_ydJzJNsf_sendMessage);
}

void Heavy_ChaffVerb::cReceive_kS2iQooj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_wtSoDNbN_sendMessage);
}

void Heavy_ChaffVerb::cReceive_tFUwdQsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wgl9bkov_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gGZMaVEH_sendMessage);
}

void Heavy_ChaffVerb::cReceive_4ntEUaj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZjzpdXjI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7OiSWEtr_sendMessage);
}

void Heavy_ChaffVerb::cReceive_tv8SeIkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ibdxxev7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lYNJjWHJ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_eXz4z9oQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gTcKVELl, m);
}

void Heavy_ChaffVerb::cReceive_91uMFuBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3MBS3tvK, m);
}

void Heavy_ChaffVerb::cReceive_en8K2huC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sb3msu5S, 0, m, &cVar_Sb3msu5S_sendMessage);
}

void Heavy_ChaffVerb::cReceive_oTo5enLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_WJNHyY4i_sendMessage);
}

void Heavy_ChaffVerb::cReceive_rNd5C1Hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XFEgbzvp, 0, m, &cVar_XFEgbzvp_sendMessage);
}

void Heavy_ChaffVerb::cReceive_FiXPPwnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qYCweP8T, 0, m, &cVar_qYCweP8T_sendMessage);
}

void Heavy_ChaffVerb::cReceive_jqRzHgu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nSbWqOgd, 0, m, &cVar_nSbWqOgd_sendMessage);
}

void Heavy_ChaffVerb::cReceive_2xfLWu1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zm8AM6oN, m);
}

void Heavy_ChaffVerb::cReceive_fUynZdpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3Agh9jvP, m);
}

void Heavy_ChaffVerb::cReceive_3Wmc3ZMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XydBZroK, HV_BINOP_MULTIPLY, 1, m, &cBinop_XydBZroK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BLn0fns5_sendMessage);
}

void Heavy_ChaffVerb::cReceive_yrwicUs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AkwMCd7w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BlYHhPHa_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_ppRcYNGN, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_lch0oisU, VOf(Bf4));
    __hv_line_f(&sLine_Tvq6peL0, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_wEIul4rI, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_XS4FGTD5, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_0UvsKo7Z, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_QtIL0rn0, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_4lq60lga, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_VT0SnUzQ, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_8xJKFYgk, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_6K12GXX9, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_cdZWQDfu, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_3kmzPTfP, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_jikl2ZIm, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_YuN3e68Q, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_l0v3pjVv, VIf(I0));
    __hv_varread_f(&sVarf_8ast95bf, VOf(Bf2));
    __hv_rpole_f(&sRPole_sJDesaqr, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_xtJFhx0L, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Mx6fcBx8, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_zm8AM6oN, VOf(Bf1));
    __hv_tabread_f(&sTabread_8CL64JUv, VOf(Bf5));
    __hv_varread_f(&sVarf_3Agh9jvP, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_Gi2itpse, VIf(Bf9));
    __hv_varread_f(&sVarf_3MBS3tvK, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_UoQ0vKCA, VOf(Bf9));
    __hv_varread_f(&sVarf_VypEsHX0, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_OZkm92vB, VOf(Bf2));
    __hv_rpole_f(&sRPole_JzAlQyH5, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_dAYgHCK0, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_xanK1odK, VOf(Bf2));
    __hv_tabread_f(&sTabread_k9qNzWUH, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_ND6Qevho, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_lpoU3cAm, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_ty0k8Ros, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_xkzta5HU, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_Uhcv57ms, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_ClZu3Zl9, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_3hr2lOhj, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_T6lcn9rJ, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_ETw3W8dB, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_lc4Ag43H, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_r7FOShdG, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_S7xJkpS3, VOf(Bf9));
    __hv_varread_f(&sVarf_CacsI8l9, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_Py3j6gt0, VOf(Bf3));
    __hv_rpole_f(&sRPole_9iABMgkg, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_x0pWAuRM, VOf(Bf3));
    __hv_varread_f(&sVarf_6hY6qzRm, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_mBoQjvqh, VOf(Bf12));
    __hv_rpole_f(&sRPole_VuLQRRTZ, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_ttPuCrK9, VOf(Bf12));
    __hv_varread_f(&sVarf_o9jWtfAP, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_MUNheMJU, VOf(Bf11));
    __hv_rpole_f(&sRPole_m9O1ThvH, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_eErH9xec, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_J9IhJjcq, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_B4ISYUzw, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_RlipCkZz, VIf(Bf11));
    __hv_line_f(&sLine_rzfDCGjt, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_gTcKVELl, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
